"""
Exceptions for foreign words in Spanish that do not follow
standard Spanish syllabification rules

Example: "maître": "maî-tre"

Words syllabification have been extracted from educalingo dict
as there is no official resource on word syllabification
https://educalingo.com/es/dic-es

Some words were incorrectly syllabified and for this purpose DIRAE
https://dirae.es/ and the FUNDEU https://www.fundeu.es/dudas/
have been consulted to resolve these cases.
"""

SYLLABIFICATOR_FOREIGN_WORDS_DICT = {
    "aarónica": "aa-ró-ni-ca",
    "aarónico": "aa-ró-ni-co",
    "aaronita": "aa-ro-ni-ta",
    "ampère": "am-pè-re",
    "beethoveniano": "bee-tho-ve-nia-no",
    "byroniana": "by-ro-nia-na",
    "byroniano": "by-ro-nia-no",
    # Words coming from South American languages that do not follow
    # traditional Spanish syllabification rules
    "carhuacina": "car-hua-ci-na",
    "carhuacino": "car-hua-ci-no",
    "carhuacinas": "car-hua-ci-nas",
    "carhuacinos": "car-hua-ci-nos",
    "chiismo": "chi-is-mo",
    "chiita": "chi-i-ta",
    "christmas": "christ-mas",
    "coihaiquina": "co-ihai-qui-na",
    "coihaiquino": "co-ihai-qui-no",
    "coihue": "coi-hue",
    "coihué": "coi-hué",
    "copyright": "co-py-right",
    "curaçao": "cu-ra-ça-o",
    "darwiniano": "dar-wi-nia-no",
    "darwinismo": "dar-wi-nis-mo",
    "darwinista": "dar-wi-nis-ta",
    "dseda": "dse-da",
    "duunvir": "du-un-vir",
    "duunviral": "du-un-vi-ral",
    "duunvirato": "du-un-vi-ra-to",
    "duunviro": "du-un-vi-ro",
    "emmenthal": "e-mmen-thal",
    "hardware": "hard-ware",
    "hollywoodiano": "holly-woo-dia-no",
    "hollywoodiense": "ho-lly-woo-dien-se",
    "maître": "maî-tre",
    "neodarwinismo": "ne-o-dar-wi-nis-mo",
    "neodarwinista": "ne-o-dar-wi-nis-ta",
    "pajla": "paj-la",
    "penthouse": "pent-house",
    # Quechuan word with different syllabification
    "pirhuín": "pir-huín",
    "première": "pre-miè-re",
    "priismo": "pri-is-mo",
    "priista": "pri-is-ta",
    "puruhá": "pur-uhá",
    "rottweiler": "rott-wei-ler",
    "sandwich": "sand-wich",
    "sándwich": "sánd-wich",
    "sandwichera": "sand-wi-che-ra",
    "sandwichería": "sand-wi-che-rí-a",
    "schnauzer": "sch-nau-zer",
    "score": "s-core",
    "shakesperiano": "sha-kes-pe-ria-no",
    "shapra": "sha-pra",
    "shaurire": "shau-ri-re",
    "shawarma": "sha-war-ma",
    "shekel": "she-kel",
    "sherpa": "sher-pa",
    "shute": "shu-te",
    "singspiel": "sings-piel",
    "snooker": "s-noo-ker",
    "software": "soft-ware",
    "spaghetti": "s-pa-ghe-ti",
    "spinning": "s-pi-nning",
    "srilanqués": "sri-lan-qués",
    "staccato": "s-ta-cca-to",
    "stage": "s-tage",
    "standing": "s-tan-ding",
    "starlette": "s-tar-le-tte",
    "taekwondista": "ta-e-kwon-dis-ta",
    "taekwondo": "ta-e-kwon-do",
    "tarhui": "tar-hui",
    "taylorismo": "tay-lo-ris-mo",
    "tsunami": "tsu-na-mi",
    "tzeltal": "tzel-tal",
    "tzompantli": "tzom-pan-tli",
    "whippet": "whip-pet",
    "whiskería": "whis-ke-rí-a",
    "yihad": "yi-had"}

"""
Phonetic exceptions dict for potential diaeresis

paranoia': (['pa', 'ra', 'noia'], # Normative syllabification
         [
         (['pa', 'ra', 'no', 'ia'], (2, 3)), # Items to mark as a metaplasm
         (['pa', 'ra', 'no', 'i', 'a'], (2, 3, 4)) # Another example
        ]),
"""

ALTERNATIVE_SYLLABIFICATION = {
    'acentual': (['a', 'cen', 'tual'], [(['a', 'cen', 'tu', 'al'], (2, 3))]),
    'actual': (['ac', 'tual'], [(['ac', 'tu', 'al'], (1, 2))]),
    'actualmente': (['ac', 'tual', 'men', 'te'],
                    [(['ac', 'tu', 'al', 'men', 'te'], (1, 2))]),
    'alioli': (['a', 'lio', 'li'], [(['a', 'li', 'o', 'li'], (1, 2))]),
    'aliolis': (['a', 'lio', 'lis'], [(['a', 'li', 'o', 'lis'], (1, 2))]),
    'altruismo': (['al', 'truis', 'mo'], [(['al', 'tru', 'is', 'mo'], (1, 2))]),
    'altruismos': (['al', 'truis', 'mos'],
                   [(['al', 'tru', 'is', 'mos'], (1, 2))]),
    'altruista': (['al', 'truis', 'ta'], [(['al', 'tru', 'is', 'ta'], (1, 2))]),
    'altruistas': (['al', 'truis', 'tas'],
                   [(['al', 'tru', 'is', 'tas'], (1, 2))]),
    'anual': (['a', 'nual'], [(['a', 'nu', 'al'], (1, 2))]),
    'apriorismo': (['a', 'prio', 'ris', 'mo'],
                   [(['a', 'pri', 'o', 'ris', 'mo'], (1, 2))]),
    'apriorismos': (['a', 'prio', 'ris', 'mos'],
                    [(['a', 'pri', 'o', 'ris', 'mos'], (1, 2))]),
    'arcaicemos': (['ar', 'cai', 'ce', 'mos'],
                   [(['ar', 'ca', 'i', 'ce', 'mos'], (1, 2))]),
    'arcaicé': (['ar', 'cai', 'cé'], [(['ar', 'cai', 'cé'], (1, 2))]),
    'arcaicéis': (['ar', 'cai', 'céis'], [(['ar', 'cai', 'céis'], (1, 2))]),
    'arcaizaba': (['ar', 'cai', 'za', 'ba'],
                  [(['ar', 'ca', 'i', 'za', 'ba'], (1, 2))]),
    'arcaizabais': (['ar', 'cai', 'za', 'bais'],
                    [(['ar', 'ca', 'i', 'za', 'bais'], (1, 2))]),
    'arcaizaban': (['ar', 'cai', 'za', 'ban'],
                   [(['ar', 'ca', 'i', 'za', 'ban'], (1, 2))]),
    'arcaizabas': (['ar', 'cai', 'za', 'bas'],
                   [(['ar', 'ca', 'i', 'za', 'bas'], (1, 2))]),
    'arcaizad': (['ar', 'cai', 'zad'], [(['ar', 'ca', 'i', 'zad'], (1, 2))]),
    'arcaizado': (['ar', 'cai', 'za', 'do'],
                  [(['ar', 'ca', 'i', 'za', 'do'], (1, 2))]),
    'arcaizamos': (['ar', 'cai', 'za', 'mos'],
                   [(['ar', 'ca', 'i', 'za', 'mos'], (1, 2))]),
    'arcaizando': (['ar', 'cai', 'zan', 'do'],
                   [(['ar', 'ca', 'i', 'zan', 'do'], (1, 2))]),
    'arcaizar': (['ar', 'cai', 'zar'], [(['ar', 'ca', 'i', 'zar'], (1, 2))]),
    'arcaizara': (['ar', 'cai', 'za', 'ra'],
                  [(['ar', 'ca', 'i', 'za', 'ra'], (1, 2))]),
    'arcaizarais': (['ar', 'cai', 'za', 'rais'],
                    [(['ar', 'ca', 'i', 'za', 'rais'], (1, 2))]),
    'arcaizaran': (['ar', 'cai', 'za', 'ran'],
                   [(['ar', 'ca', 'i', 'za', 'ran'], (1, 2))]),
    'arcaizaras': (['ar', 'cai', 'za', 'ras'],
                   [(['ar', 'ca', 'i', 'za', 'ras'], (1, 2))]),
    'arcaizare': (['ar', 'cai', 'za', 're'],
                  [(['ar', 'ca', 'i', 'za', 're'], (1, 2))]),
    'arcaizareis': (['ar', 'cai', 'za', 'reis'],
                    [(['ar', 'ca', 'i', 'za', 'reis'], (1, 2))]),
    'arcaizaremos': (['ar', 'cai', 'za', 're', 'mos'],
                     [(['ar', 'ca', 'i', 'za', 're', 'mos'], (1, 2))]),
    'arcaizaren': (['ar', 'cai', 'za', 'ren'],
                   [(['ar', 'ca', 'i', 'za', 'ren'], (1, 2))]),
    'arcaizares': (['ar', 'cai', 'za', 'res'],
                   [(['ar', 'ca', 'i', 'za', 'res'], (1, 2))]),
    'arcaizaron': (['ar', 'cai', 'za', 'ron'],
                   [(['ar', 'ca', 'i', 'za', 'ron'], (1, 2))]),
    'arcaizará': (['ar', 'cai', 'za', 'rá'],
                  [(['ar', 'ca', 'i', 'za', 'rá'], (1, 2))]),
    'arcaizarán': (['ar', 'cai', 'za', 'rán'],
                   [(['ar', 'ca', 'i', 'za', 'rán'], (1, 2))]),
    'arcaizarás': (['ar', 'cai', 'za', 'rás'],
                   [(['ar', 'ca', 'i', 'za', 'rás'], (1, 2))]),
    'arcaizaré': (['ar', 'cai', 'za', 'ré'],
                  [(['ar', 'ca', 'i', 'za', 'ré'], (1, 2))]),
    'arcaizaréis': (['ar', 'cai', 'za', 'réis'],
                    [(['ar', 'ca', 'i', 'za', 'réis'], (1, 2))]),
    'arcaizaría': (['ar', 'cai', 'za', 'rí', 'a'],
                   [(['ar', 'ca', 'i', 'za', 'rí', 'a'], (1, 2))]),
    'arcaizaríais': (['ar', 'cai', 'za', 'rí', 'ais'],
                     [(['ar', 'ca', 'i', 'za', 'rí', 'ais'], (1, 2))]),
    'arcaizaríamos': (['ar', 'cai', 'za', 'rí', 'a', 'mos'],
                      [(['ar', 'ca', 'i', 'za', 'rí', 'a', 'mos'], (1, 2))]),
    'arcaizarían': (['ar', 'cai', 'za', 'rí', 'an'],
                    [(['ar', 'ca', 'i', 'za', 'rí', 'an'], (1, 2))]),
    'arcaizarías': (['ar', 'cai', 'za', 'rí', 'as'],
                    [(['ar', 'ca', 'i', 'za', 'rí', 'as'], (1, 2))]),
    'arcaizase': (['ar', 'cai', 'za', 'se'],
                  [(['ar', 'ca', 'i', 'za', 'se'], (1, 2))]),
    'arcaizaseis': (['ar', 'cai', 'za', 'seis'],
                    [(['ar', 'ca', 'i', 'za', 'seis'], (1, 2))]),
    'arcaizasen': (['ar', 'cai', 'za', 'sen'],
                   [(['ar', 'ca', 'i', 'za', 'sen'], (1, 2))]),
    'arcaizases': (['ar', 'cai', 'za', 'ses'],
                   [(['ar', 'ca', 'i', 'za', 'ses'], (1, 2))]),
    'arcaizaste': (['ar', 'cai', 'zas', 'te'],
                   [(['ar', 'ca', 'i', 'zas', 'te'], (1, 2))]),
    'arcaizasteis': (['ar', 'cai', 'zas', 'teis'],
                     [(['ar', 'ca', 'i', 'zas', 'teis'], (1, 2))]),
    'arcaizá': (['ar', 'cai', 'zá'], [(['ar', 'ca', 'i', 'zá'], (1, 2))]),
    'arcaizábamos': (['ar', 'cai', 'zá', 'ba', 'mos'],
                     [(['ar', 'ca', 'i', 'zá', 'ba', 'mos'], (1, 2))]),
    'arcaizáis': (['ar', 'cai', 'záis'], [(['ar', 'ca', 'i', 'záis'], (1, 2))]),
    'arcaizáramos': (['ar', 'cai', 'zá', 'ra', 'mos'],
                     [(['ar', 'ca', 'i', 'zá', 'ra', 'mos'], (1, 2))]),
    'arcaizáremos': (['ar', 'cai', 'zá', 're', 'mos'],
                     [(['ar', 'ca', 'i', 'zá', 're', 'mos'], (1, 2))]),
    'arcaizás': (['ar', 'cai', 'zás'], [(['ar', 'ca', 'i', 'zás'], (1, 2))]),
    'arcaizásemos': (['ar', 'cai', 'zá', 'se', 'mos'],
                     [(['ar', 'ca', 'i', 'zá', 'se', 'mos'], (1, 2))]),
    'arcaizó': (['ar', 'cai', 'zó'], [(['ar', 'ca', 'i', 'zó'], (1, 2))]),
    'arriada': (['a', 'rria', 'da'], [(['a', 'rri', 'a', 'da'], (1, 2))]),
    'arriadas': (['a', 'rria', 'das'], [(['a', 'rri', 'a', 'das'], (1, 2))]),
    'arriata': (['a', 'rria', 'ta'], [(['a', 'rri', 'a', 'ta'], (1, 2))]),
    'arriatas': (['a', 'rria', 'tas'], [(['a', 'rri', 'a', 'tas'], (1, 2))]),
    'arriate': (['a', 'rria', 'te'], [(['a', 'rri', 'a', 'te'], (1, 2))]),
    'arriates': (['a', 'rria', 'tes'], [(['a', 'rri', 'a', 'tes'], (1, 2))]),
    'arriero': (['a', 'rrie', 'ro'], [(['a', 'rri', 'e', 'ro'], (1, 2))]),
    'arrieros': (['a', 'rrie', 'ros'], [(['a', 'rri', 'e', 'ros'], (1, 2))]),
    'arriería': (['a', 'rrie', 'rí', 'a'],
                 [(['a', 'rri', 'e', 'rí', 'a'], (1, 2))]),
    'arrierías': (['a', 'rrie', 'rí', 'as'],
                  [(['a', 'rri', 'e', 'rí', 'as'], (1, 2))]),
    'asexuado': (['a', 'se', 'xua', 'do'],
                 [(['a', 'se', 'xu', 'a', 'do'], (2, 3))]),
    'asexuados': (['a', 'se', 'xua', 'dos'],
                  [(['a', 'se', 'xu', 'a', 'dos'], (2, 3))]),
    'asexual': (['a', 'se', 'xual'], [(['a', 'se', 'xu', 'al'], (2, 3))]),
    'atraillaba': (['a', 'trai', 'lla', 'ba'],
                   [(['a', 'tra', 'i', 'lla', 'ba'], (1, 2))]),
    'atraillabais': (['a', 'trai', 'lla', 'bais'],
                     [(['a', 'tra', 'i', 'lla', 'bais'], (1, 2))]),
    'atraillaban': (['a', 'trai', 'lla', 'ban'],
                    [(['a', 'tra', 'i', 'lla', 'ban'], (1, 2))]),
    'atraillabas': (['a', 'trai', 'lla', 'bas'],
                    [(['a', 'tra', 'i', 'lla', 'bas'], (1, 2))]),
    'atraillad': (['a', 'trai', 'llad'], [(['a', 'tra', 'i', 'llad'], (1, 2))]),
    'atraillado': (['a', 'trai', 'lla', 'do'],
                   [(['a', 'tra', 'i', 'lla', 'do'], (1, 2))]),
    'atraillamos': (['a', 'trai', 'lla', 'mos'],
                    [(['a', 'tra', 'i', 'lla', 'mos'], (1, 2))]),
    'atraillando': (['a', 'trai', 'llan', 'do'],
                    [(['a', 'tra', 'i', 'llan', 'do'], (1, 2))]),
    'atraillar': (['a', 'trai', 'llar'], [(['a', 'tra', 'i', 'llar'], (1, 2))]),
    'atraillara': (['a', 'trai', 'lla', 'ra'],
                   [(['a', 'tra', 'i', 'lla', 'ra'], (1, 2))]),
    'atraillarais': (['a', 'trai', 'lla', 'rais'],
                     [(['a', 'tra', 'i', 'lla', 'rais'], (1, 2))]),
    'atraillaran': (['a', 'trai', 'lla', 'ran'],
                    [(['a', 'tra', 'i', 'lla', 'ran'], (1, 2))]),
    'atraillaras': (['a', 'trai', 'lla', 'ras'],
                    [(['a', 'tra', 'i', 'lla', 'ras'], (1, 2))]),
    'atraillare': (['a', 'trai', 'lla', 're'],
                   [(['a', 'tra', 'i', 'lla', 're'], (1, 2))]),
    'atraillareis': (['a', 'trai', 'lla', 'reis'],
                     [(['a', 'tra', 'i', 'lla', 'reis'], (1, 2))]),
    'atraillaremos': (['a', 'trai', 'lla', 're', 'mos'],
                      [(['a', 'tra', 'i', 'lla', 're', 'mos'], (1, 2))]),
    'atraillaren': (['a', 'trai', 'lla', 'ren'],
                    [(['a', 'tra', 'i', 'lla', 'ren'], (1, 2))]),
    'atraillares': (['a', 'trai', 'lla', 'res'],
                    [(['a', 'tra', 'i', 'lla', 'res'], (1, 2))]),
    'atraillaron': (['a', 'trai', 'lla', 'ron'],
                    [(['a', 'tra', 'i', 'lla', 'ron'], (1, 2))]),
    'atraillará': (['a', 'trai', 'lla', 'rá'],
                   [(['a', 'tra', 'i', 'lla', 'rá'], (1, 2))]),
    'atraillarán': (['a', 'trai', 'lla', 'rán'],
                    [(['a', 'tra', 'i', 'lla', 'rán'], (1, 2))]),
    'atraillarás': (['a', 'trai', 'lla', 'rás'],
                    [(['a', 'tra', 'i', 'lla', 'rás'], (1, 2))]),
    'atraillaré': (['a', 'trai', 'lla', 'ré'],
                   [(['a', 'tra', 'i', 'lla', 'ré'], (1, 2))]),
    'atraillaréis': (['a', 'trai', 'lla', 'réis'],
                     [(['a', 'tra', 'i', 'lla', 'réis'], (1, 2))]),
    'atraillaría': (['a', 'trai', 'lla', 'rí', 'a'],
                    [(['a', 'tra', 'i', 'lla', 'rí', 'a'], (1, 2))]),
    'atraillaríais': (['a', 'trai', 'lla', 'rí', 'ais'],
                      [(['a', 'tra', 'i', 'lla', 'rí', 'ais'], (1, 2))]),
    'atraillaríamos': (['a', 'trai', 'lla', 'rí', 'a', 'mos'],
                       [(['a', 'tra', 'i', 'lla', 'rí', 'a', 'mos'], (1, 2))]),
    'atraillarían': (['a', 'trai', 'lla', 'rí', 'an'],
                     [(['a', 'tra', 'i', 'lla', 'rí', 'an'], (1, 2))]),
    'atraillarías': (['a', 'trai', 'lla', 'rí', 'as'],
                     [(['a', 'tra', 'i', 'lla', 'rí', 'as'], (1, 2))]),
    'atraillase': (['a', 'trai', 'lla', 'se'],
                   [(['a', 'tra', 'i', 'lla', 'se'], (1, 2))]),
    'atraillaseis': (['a', 'trai', 'lla', 'seis'],
                     [(['a', 'tra', 'i', 'lla', 'seis'], (1, 2))]),
    'atraillasen': (['a', 'trai', 'lla', 'sen'],
                    [(['a', 'tra', 'i', 'lla', 'sen'], (1, 2))]),
    'atraillases': (['a', 'trai', 'lla', 'ses'],
                    [(['a', 'tra', 'i', 'lla', 'ses'], (1, 2))]),
    'atraillaste': (['a', 'trai', 'llas', 'te'],
                    [(['a', 'tra', 'i', 'llas', 'te'], (1, 2))]),
    'atraillasteis': (['a', 'trai', 'llas', 'teis'],
                      [(['a', 'tra', 'i', 'llas', 'teis'], (1, 2))]),
    'atraillemos': (['a', 'trai', 'lle', 'mos'],
                    [(['a', 'tra', 'i', 'lle', 'mos'], (1, 2))]),
    'atraillá': (['a', 'trai', 'llá'], [(['a', 'tra', 'i', 'llá'], (1, 2))]),
    'atraillábamos': (['a', 'trai', 'llá', 'ba', 'mos'],
                      [(['a', 'tra', 'i', 'llá', 'ba', 'mos'], (1, 2))]),
    'atrailláis': (['a', 'trai', 'lláis'],
                   [(['a', 'tra', 'i', 'lláis'], (1, 2))]),
    'atrailláramos': (['a', 'trai', 'llá', 'ra', 'mos'],
                      [(['a', 'tra', 'i', 'llá', 'ra', 'mos'], (1, 2))]),
    'atrailláremos': (['a', 'trai', 'llá', 're', 'mos'],
                      [(['a', 'tra', 'i', 'llá', 're', 'mos'], (1, 2))]),
    'atraillás': (['a', 'trai', 'llás'], [(['a', 'tra', 'i', 'llás'], (1, 2))]),
    'atraillásemos': (['a', 'trai', 'llá', 'se', 'mos'],
                      [(['a', 'tra', 'i', 'llá', 'se', 'mos'], (1, 2))]),
    'atraillé': (['a', 'trai', 'llé'], [(['a', 'tra', 'i', 'llé'], (1, 2))]),
    'atrailléis': (['a', 'trai', 'lléis'],
                   [(['a', 'tra', 'i', 'lléis'], (1, 2))]),
    'atrailló': (['a', 'trai', 'lló'], [(['a', 'tra', 'i', 'lló'], (1, 2))]),
    'audiovisual': (['au', 'dio', 'vi', 'sual'],
                    [(['au', 'dio', 'vi', 'su', 'al'], (3, 4))]),
    'aullaba': (['au', 'lla', 'ba'], [(['a', 'u', 'lla', 'ba'], (0, 1))]),
    'aullabais': (['au', 'lla', 'bais'], [(['a', 'u', 'lla', 'bais'], (0, 1))]),
    'aullaban': (['au', 'lla', 'ban'], [(['a', 'u', 'lla', 'ban'], (0, 1))]),
    'aullabas': (['au', 'lla', 'bas'], [(['a', 'u', 'lla', 'bas'], (0, 1))]),
    'aullad': (['au', 'llad'], [(['a', 'u', 'llad'], (0, 1))]),
    'aulladero': (['au', 'lla', 'de', 'ro'],
                  [(['au', 'lla', 'de', 'ro'], (0, 1))]),
    'aullado': (['au', 'lla', 'do'], [(['a', 'u', 'lla', 'do'], (0, 1))]),
    'aullamos': (['au', 'lla', 'mos'], [(['a', 'u', 'lla', 'mos'], (0, 1))]),
    'aullando': (['au', 'llan', 'do'], [(['a', 'u', 'llan', 'do'], (0, 1))]),
    'aullante': (['au', 'llan', 'te'], [(['au', 'llan', 'te'], (0, 1))]),
    'aullar': (['au', 'llar'], [(['a', 'u', 'llar'], (0, 1))]),
    'aullara': (['au', 'lla', 'ra'], [(['a', 'u', 'lla', 'ra'], (0, 1))]),
    'aullarais': (['au', 'lla', 'rais'], [(['a', 'u', 'lla', 'rais'], (0, 1))]),
    'aullaran': (['au', 'lla', 'ran'], [(['a', 'u', 'lla', 'ran'], (0, 1))]),
    'aullaras': (['au', 'lla', 'ras'], [(['a', 'u', 'lla', 'ras'], (0, 1))]),
    'aullare': (['au', 'lla', 're'], [(['a', 'u', 'lla', 're'], (0, 1))]),
    'aullareis': (['au', 'lla', 'reis'], [(['a', 'u', 'lla', 'reis'], (0, 1))]),
    'aullaremos': (['au', 'lla', 're', 'mos'],
                   [(['a', 'u', 'lla', 're', 'mos'], (0, 1))]),
    'aullaren': (['au', 'lla', 'ren'], [(['a', 'u', 'lla', 'ren'], (0, 1))]),
    'aullares': (['au', 'lla', 'res'], [(['a', 'u', 'lla', 'res'], (0, 1))]),
    'aullaron': (['au', 'lla', 'ron'], [(['a', 'u', 'lla', 'ron'], (0, 1))]),
    'aullará': (['au', 'lla', 'rá'], [(['a', 'u', 'lla', 'rá'], (0, 1))]),
    'aullarán': (['au', 'lla', 'rán'], [(['a', 'u', 'lla', 'rán'], (0, 1))]),
    'aullarás': (['au', 'lla', 'rás'], [(['a', 'u', 'lla', 'rás'], (0, 1))]),
    'aullaré': (['au', 'lla', 'ré'], [(['a', 'u', 'lla', 'ré'], (0, 1))]),
    'aullaréis': (['au', 'lla', 'réis'], [(['a', 'u', 'lla', 'réis'], (0, 1))]),
    'aullaría': (['au', 'lla', 'rí', 'a'],
                 [(['a', 'u', 'lla', 'rí', 'a'], (0, 1))]),
    'aullaríais': (['au', 'lla', 'rí', 'ais'],
                   [(['a', 'u', 'lla', 'rí', 'ais'], (0, 1))]),
    'aullaríamos': (['au', 'lla', 'rí', 'a', 'mos'],
                    [(['a', 'u', 'lla', 'rí', 'a', 'mos'], (0, 1))]),
    'aullarían': (['au', 'lla', 'rí', 'an'],
                  [(['a', 'u', 'lla', 'rí', 'an'], (0, 1))]),
    'aullarías': (['au', 'lla', 'rí', 'as'],
                  [(['a', 'u', 'lla', 'rí', 'as'], (0, 1))]),
    'aullase': (['au', 'lla', 'se'], [(['a', 'u', 'lla', 'se'], (0, 1))]),
    'aullaseis': (['au', 'lla', 'seis'], [(['a', 'u', 'lla', 'seis'], (0, 1))]),
    'aullasen': (['au', 'lla', 'sen'], [(['a', 'u', 'lla', 'sen'], (0, 1))]),
    'aullases': (['au', 'lla', 'ses'], [(['a', 'u', 'lla', 'ses'], (0, 1))]),
    'aullaste': (['au', 'llas', 'te'], [(['a', 'u', 'llas', 'te'], (0, 1))]),
    'aullasteis': (['au', 'llas', 'teis'],
                   [(['a', 'u', 'llas', 'teis'], (0, 1))]),
    'aullemos': (['au', 'lle', 'mos'], [(['a', 'u', 'lle', 'mos'], (0, 1))]),
    'aullido': (['au', 'lli', 'do'], [(['au', 'lli', 'do'], (0, 1))]),
    'aullá': (['au', 'llá'], [(['a', 'u', 'llá'], (0, 1))]),
    'aullábamos': (['au', 'llá', 'ba', 'mos'],
                   [(['a', 'u', 'llá', 'ba', 'mos'], (0, 1))]),
    'aulláis': (['au', 'lláis'], [(['a', 'u', 'lláis'], (0, 1))]),
    'aulláramos': (['au', 'llá', 'ra', 'mos'],
                   [(['a', 'u', 'llá', 'ra', 'mos'], (0, 1))]),
    'aulláremos': (['au', 'llá', 're', 'mos'],
                   [(['a', 'u', 'llá', 're', 'mos'], (0, 1))]),
    'aullás': (['au', 'llás'], [(['a', 'u', 'llás'], (0, 1))]),
    'aullásemos': (['au', 'llá', 'se', 'mos'],
                   [(['a', 'u', 'llá', 'se', 'mos'], (0, 1))]),
    'aullé': (['au', 'llé'], [(['a', 'u', 'llé'], (0, 1))]),
    'aulléis': (['au', 'lléis'], [(['a', 'u', 'lléis'], (0, 1))]),
    'aulló': (['au', 'lló'], [(['a', 'u', 'lló'], (0, 1))]),
    'aunaba': (['au', 'na', 'ba'], [(['a', 'u', 'na', 'ba'], (0, 1))]),
    'aunabais': (['au', 'na', 'bais'], [(['a', 'u', 'na', 'bais'], (0, 1))]),
    'aunaban': (['au', 'na', 'ban'], [(['a', 'u', 'na', 'ban'], (0, 1))]),
    'aunabas': (['au', 'na', 'bas'], [(['a', 'u', 'na', 'bas'], (0, 1))]),
    'aunable': (['au', 'na', 'ble'], [(['au', 'na', 'ble'], (0, 1))]),
    'aunad': (['au', 'nad'], [(['a', 'u', 'nad'], (0, 1))]),
    'aunado': (['au', 'na', 'do'], [(['a', 'u', 'na', 'do'], (0, 1))]),
    'aunamiento': (['au', 'na', 'mien', 'to'],
                   [(['au', 'na', 'mien', 'to'], (0, 1))]),
    'aunamos': (['au', 'na', 'mos'], [(['a', 'u', 'na', 'mos'], (0, 1))]),
    'aunando': (['au', 'nan', 'do'], [(['a', 'u', 'nan', 'do'], (0, 1))]),
    'aunar': (['au', 'nar'], [(['a', 'u', 'nar'], (0, 1))]),
    'aunara': (['au', 'na', 'ra'], [(['a', 'u', 'na', 'ra'], (0, 1))]),
    'aunarais': (['au', 'na', 'rais'], [(['a', 'u', 'na', 'rais'], (0, 1))]),
    'aunaran': (['au', 'na', 'ran'], [(['a', 'u', 'na', 'ran'], (0, 1))]),
    'aunaras': (['au', 'na', 'ras'], [(['a', 'u', 'na', 'ras'], (0, 1))]),
    'aunare': (['au', 'na', 're'], [(['a', 'u', 'na', 're'], (0, 1))]),
    'aunareis': (['au', 'na', 'reis'], [(['a', 'u', 'na', 'reis'], (0, 1))]),
    'aunaremos': (['au', 'na', 're', 'mos'],
                  [(['a', 'u', 'na', 're', 'mos'], (0, 1))]),
    'aunaren': (['au', 'na', 'ren'], [(['a', 'u', 'na', 'ren'], (0, 1))]),
    'aunares': (['au', 'na', 'res'], [(['a', 'u', 'na', 'res'], (0, 1))]),
    'aunaron': (['au', 'na', 'ron'], [(['a', 'u', 'na', 'ron'], (0, 1))]),
    'aunará': (['au', 'na', 'rá'], [(['a', 'u', 'na', 'rá'], (0, 1))]),
    'aunarán': (['au', 'na', 'rán'], [(['a', 'u', 'na', 'rán'], (0, 1))]),
    'aunarás': (['au', 'na', 'rás'], [(['a', 'u', 'na', 'rás'], (0, 1))]),
    'aunaré': (['au', 'na', 'ré'], [(['a', 'u', 'na', 'ré'], (0, 1))]),
    'aunaréis': (['au', 'na', 'réis'], [(['a', 'u', 'na', 'réis'], (0, 1))]),
    'aunaría': (['au', 'na', 'rí', 'a'],
                [(['a', 'u', 'na', 'rí', 'a'], (0, 1))]),
    'aunaríais': (['au', 'na', 'rí', 'ais'],
                  [(['a', 'u', 'na', 'rí', 'ais'], (0, 1))]),
    'aunaríamos': (['au', 'na', 'rí', 'a', 'mos'],
                   [(['a', 'u', 'na', 'rí', 'a', 'mos'], (0, 1))]),
    'aunarían': (['au', 'na', 'rí', 'an'],
                 [(['a', 'u', 'na', 'rí', 'an'], (0, 1))]),
    'aunarías': (['au', 'na', 'rí', 'as'],
                 [(['a', 'u', 'na', 'rí', 'as'], (0, 1))]),
    'aunase': (['au', 'na', 'se'], [(['a', 'u', 'na', 'se'], (0, 1))]),
    'aunaseis': (['au', 'na', 'seis'], [(['a', 'u', 'na', 'seis'], (0, 1))]),
    'aunasen': (['au', 'na', 'sen'], [(['a', 'u', 'na', 'sen'], (0, 1))]),
    'aunases': (['au', 'na', 'ses'], [(['a', 'u', 'na', 'ses'], (0, 1))]),
    'aunaste': (['au', 'nas', 'te'], [(['a', 'u', 'nas', 'te'], (0, 1))]),
    'aunasteis': (['au', 'nas', 'teis'], [(['a', 'u', 'nas', 'teis'], (0, 1))]),
    'aunemos': (['au', 'ne', 'mos'], [(['a', 'u', 'ne', 'mos'], (0, 1))]),
    'auná': (['au', 'ná'], [(['a', 'u', 'ná'], (0, 1))]),
    'aunábamos': (['au', 'ná', 'ba', 'mos'],
                  [(['a', 'u', 'ná', 'ba', 'mos'], (0, 1))]),
    'aunáis': (['au', 'náis'], [(['a', 'u', 'náis'], (0, 1))]),
    'aunáramos': (['au', 'ná', 'ra', 'mos'],
                  [(['a', 'u', 'ná', 'ra', 'mos'], (0, 1))]),
    'aunáremos': (['au', 'ná', 're', 'mos'],
                  [(['a', 'u', 'ná', 're', 'mos'], (0, 1))]),
    'aunás': (['au', 'nás'], [(['a', 'u', 'nás'], (0, 1))]),
    'aunásemos': (['au', 'ná', 'se', 'mos'],
                  [(['a', 'u', 'ná', 'se', 'mos'], (0, 1))]),
    'auné': (['au', 'né'], [(['a', 'u', 'né'], (0, 1))]),
    'aunéis': (['au', 'néis'], [(['a', 'u', 'néis'], (0, 1))]),
    'aunó': (['au', 'nó'], [(['au', 'nó'], (0, 1))]),
    'aupaba': (['au', 'pa', 'ba'], [(['a', 'u', 'pa', 'ba'], (0, 1))]),
    'aupabais': (['au', 'pa', 'bais'], [(['a', 'u', 'pa', 'bais'], (0, 1))]),
    'aupaban': (['au', 'pa', 'ban'], [(['a', 'u', 'pa', 'ban'], (0, 1))]),
    'aupabas': (['au', 'pa', 'bas'], [(['a', 'u', 'pa', 'bas'], (0, 1))]),
    'aupad': (['au', 'pad'], [(['a', 'u', 'pad'], (0, 1))]),
    'aupado': (['au', 'pa', 'do'], [(['a', 'u', 'pa', 'do'], (0, 1))]),
    'aupamos': (['au', 'pa', 'mos'], [(['a', 'u', 'pa', 'mos'], (0, 1))]),
    'aupando': (['au', 'pan', 'do'], [(['a', 'u', 'pan', 'do'], (0, 1))]),
    'aupar': (['au', 'par'], [(['a', 'u', 'par'], (0, 1))]),
    'aupara': (['au', 'pa', 'ra'], [(['a', 'u', 'pa', 'ra'], (0, 1))]),
    'auparais': (['au', 'pa', 'rais'], [(['a', 'u', 'pa', 'rais'], (0, 1))]),
    'auparan': (['au', 'pa', 'ran'], [(['a', 'u', 'pa', 'ran'], (0, 1))]),
    'auparas': (['au', 'pa', 'ras'], [(['a', 'u', 'pa', 'ras'], (0, 1))]),
    'aupare': (['au', 'pa', 're'], [(['a', 'u', 'pa', 're'], (0, 1))]),
    'aupareis': (['au', 'pa', 'reis'], [(['a', 'u', 'pa', 'reis'], (0, 1))]),
    'auparemos': (['au', 'pa', 're', 'mos'],
                  [(['a', 'u', 'pa', 're', 'mos'], (0, 1))]),
    'auparen': (['au', 'pa', 'ren'], [(['a', 'u', 'pa', 'ren'], (0, 1))]),
    'aupares': (['au', 'pa', 'res'], [(['a', 'u', 'pa', 'res'], (0, 1))]),
    'auparon': (['au', 'pa', 'ron'], [(['a', 'u', 'pa', 'ron'], (0, 1))]),
    'aupará': (['au', 'pa', 'rá'], [(['a', 'u', 'pa', 'rá'], (0, 1))]),
    'auparán': (['au', 'pa', 'rán'], [(['a', 'u', 'pa', 'rán'], (0, 1))]),
    'auparás': (['au', 'pa', 'rás'], [(['a', 'u', 'pa', 'rás'], (0, 1))]),
    'auparé': (['au', 'pa', 'ré'], [(['a', 'u', 'pa', 'ré'], (0, 1))]),
    'auparéis': (['au', 'pa', 'réis'], [(['a', 'u', 'pa', 'réis'], (0, 1))]),
    'auparía': (['au', 'pa', 'rí', 'a'],
                [(['a', 'u', 'pa', 'rí', 'a'], (0, 1))]),
    'auparíais': (['au', 'pa', 'rí', 'ais'],
                  [(['a', 'u', 'pa', 'rí', 'ais'], (0, 1))]),
    'auparíamos': (['au', 'pa', 'rí', 'a', 'mos'],
                   [(['a', 'u', 'pa', 'rí', 'a', 'mos'], (0, 1))]),
    'auparían': (['au', 'pa', 'rí', 'an'],
                 [(['a', 'u', 'pa', 'rí', 'an'], (0, 1))]),
    'auparías': (['au', 'pa', 'rí', 'as'],
                 [(['a', 'u', 'pa', 'rí', 'as'], (0, 1))]),
    'aupase': (['au', 'pa', 'se'], [(['a', 'u', 'pa', 'se'], (0, 1))]),
    'aupaseis': (['au', 'pa', 'seis'], [(['a', 'u', 'pa', 'seis'], (0, 1))]),
    'aupasen': (['au', 'pa', 'sen'], [(['a', 'u', 'pa', 'sen'], (0, 1))]),
    'aupases': (['au', 'pa', 'ses'], [(['a', 'u', 'pa', 'ses'], (0, 1))]),
    'aupaste': (['au', 'pas', 'te'], [(['a', 'u', 'pas', 'te'], (0, 1))]),
    'aupasteis': (['au', 'pas', 'teis'], [(['a', 'u', 'pas', 'teis'], (0, 1))]),
    'aupemos': (['au', 'pe', 'mos'], [(['a', 'u', 'pe', 'mos'], (0, 1))]),
    'aupá': (['au', 'pá'], [(['a', 'u', 'pá'], (0, 1))]),
    'aupábamos': (['au', 'pá', 'ba', 'mos'],
                  [(['a', 'u', 'pá', 'ba', 'mos'], (0, 1))]),
    'aupáis': (['au', 'páis'], [(['a', 'u', 'páis'], (0, 1))]),
    'aupáramos': (['au', 'pá', 'ra', 'mos'],
                  [(['a', 'u', 'pá', 'ra', 'mos'], (0, 1))]),
    'aupáremos': (['au', 'pá', 're', 'mos'],
                  [(['a', 'u', 'pá', 're', 'mos'], (0, 1))]),
    'aupás': (['au', 'pás'], [(['a', 'u', 'pás'], (0, 1))]),
    'aupásemos': (['au', 'pá', 'se', 'mos'],
                  [(['a', 'u', 'pá', 'se', 'mos'], (0, 1))]),
    'aupé': (['au', 'pé'], [(['a', 'u', 'pé'], (0, 1))]),
    'aupéis': (['au', 'péis'], [(['a', 'u', 'péis'], (0, 1))]),
    'aupó': (['au', 'pó'], [(['a', 'u', 'pó'], (0, 1))]),
    'aúnen': (['a', 'ú', 'nen'], [(['a', 'ú', 'nen'], (0, 1))]),
    'baluarte': (['ba', 'luar', 'te'], [(['ba', 'lu', 'ar', 'te'], (1, 2))]),
    'baluartes': (['ba', 'luar', 'tes'], [(['ba', 'lu', 'ar', 'tes'], (1, 2))]),
    'baraustaba': (['ba', 'raus', 'ta', 'ba'],
                   [(['ba', 'raus', 'ta', 'ba'], (1, 2))]),
    'baraustabais': (['ba', 'raus', 'ta', 'bais'],
                     [(['ba', 'raus', 'ta', 'bais'], (1, 2))]),
    'baraustaban': (['ba', 'raus', 'ta', 'ban'],
                    [(['ba', 'raus', 'ta', 'ban'], (1, 2))]),
    'baraustabas': (['ba', 'raus', 'ta', 'bas'],
                    [(['ba', 'raus', 'ta', 'bas'], (1, 2))]),
    'baraustad': (['ba', 'raus', 'tad'], [(['ba', 'raus', 'tad'], (1, 2))]),
    'baraustado': (['ba', 'raus', 'ta', 'do'],
                   [(['ba', 'raus', 'ta', 'do'], (1, 2))]),
    'baraustamos': (['ba', 'raus', 'ta', 'mos'],
                    [(['ba', 'raus', 'ta', 'mos'], (1, 2))]),
    'baraustando': (['ba', 'raus', 'tan', 'do'],
                    [(['ba', 'raus', 'tan', 'do'], (1, 2))]),
    'baraustar': (['ba', 'raus', 'tar'], [(['ba', 'raus', 'tar'], (1, 2))]),
    'baraustara': (['ba', 'raus', 'ta', 'ra'],
                   [(['ba', 'raus', 'ta', 'ra'], (1, 2))]),
    'baraustarais': (['ba', 'raus', 'ta', 'rais'],
                     [(['ba', 'raus', 'ta', 'rais'], (1, 2))]),
    'baraustaran': (['ba', 'raus', 'ta', 'ran'],
                    [(['ba', 'raus', 'ta', 'ran'], (1, 2))]),
    'baraustaras': (['ba', 'raus', 'ta', 'ras'],
                    [(['ba', 'raus', 'ta', 'ras'], (1, 2))]),
    'baraustare': (['ba', 'raus', 'ta', 're'],
                   [(['ba', 'raus', 'ta', 're'], (1, 2))]),
    'baraustareis': (['ba', 'raus', 'ta', 'reis'],
                     [(['ba', 'raus', 'ta', 'reis'], (1, 2))]),
    'baraustaremos': (['ba', 'raus', 'ta', 're', 'mos'],
                      [(['ba', 'raus', 'ta', 're', 'mos'], (1, 2))]),
    'baraustaren': (['ba', 'raus', 'ta', 'ren'],
                    [(['ba', 'raus', 'ta', 'ren'], (1, 2))]),
    'baraustares': (['ba', 'raus', 'ta', 'res'],
                    [(['ba', 'raus', 'ta', 'res'], (1, 2))]),
    'baraustaron': (['ba', 'raus', 'ta', 'ron'],
                    [(['ba', 'raus', 'ta', 'ron'], (1, 2))]),
    'baraustará': (['ba', 'raus', 'ta', 'rá'],
                   [(['ba', 'raus', 'ta', 'rá'], (1, 2))]),
    'baraustarán': (['ba', 'raus', 'ta', 'rán'],
                    [(['ba', 'raus', 'ta', 'rán'], (1, 2))]),
    'baraustarás': (['ba', 'raus', 'ta', 'rás'],
                    [(['ba', 'raus', 'ta', 'rás'], (1, 2))]),
    'baraustaré': (['ba', 'raus', 'ta', 'ré'],
                   [(['ba', 'raus', 'ta', 'ré'], (1, 2))]),
    'baraustaréis': (['ba', 'raus', 'ta', 'réis'],
                     [(['ba', 'raus', 'ta', 'réis'], (1, 2))]),
    'baraustaría': (['ba', 'raus', 'ta', 'rí', 'a'],
                    [(['ba', 'raus', 'ta', 'rí', 'a'], (1, 2))]),
    'baraustaríais': (['ba', 'raus', 'ta', 'rí', 'ais'],
                      [(['ba', 'raus', 'ta', 'rí', 'ais'], (1, 2))]),
    'baraustaríamos': (['ba', 'raus', 'ta', 'rí', 'a', 'mos'],
                       [(['ba', 'raus', 'ta', 'rí', 'a', 'mos'], (1, 2))]),
    'baraustarían': (['ba', 'raus', 'ta', 'rí', 'an'],
                     [(['ba', 'raus', 'ta', 'rí', 'an'], (1, 2))]),
    'baraustarías': (['ba', 'raus', 'ta', 'rí', 'as'],
                     [(['ba', 'raus', 'ta', 'rí', 'as'], (1, 2))]),
    'baraustase': (['ba', 'raus', 'ta', 'se'],
                   [(['ba', 'raus', 'ta', 'se'], (1, 2))]),
    'baraustaseis': (['ba', 'raus', 'ta', 'seis'],
                     [(['ba', 'raus', 'ta', 'seis'], (1, 2))]),
    'baraustasen': (['ba', 'raus', 'ta', 'sen'],
                    [(['ba', 'raus', 'ta', 'sen'], (1, 2))]),
    'baraustases': (['ba', 'raus', 'ta', 'ses'],
                    [(['ba', 'raus', 'ta', 'ses'], (1, 2))]),
    'baraustaste': (['ba', 'raus', 'tas', 'te'],
                    [(['ba', 'raus', 'tas', 'te'], (1, 2))]),
    'baraustasteis': (['ba', 'raus', 'tas', 'teis'],
                      [(['ba', 'raus', 'tas', 'teis'], (1, 2))]),
    'baraustemos': (['ba', 'raus', 'te', 'mos'],
                    [(['ba', 'raus', 'te', 'mos'], (1, 2))]),
    'baraustá': (['ba', 'raus', 'tá'], [(['ba', 'raus', 'tá'], (1, 2))]),
    'baraustábamos': (['ba', 'raus', 'tá', 'ba', 'mos'],
                      [(['ba', 'raus', 'tá', 'ba', 'mos'], (1, 2))]),
    'baraustáis': (['ba', 'raus', 'táis'], [(['ba', 'raus', 'táis'], (1, 2))]),
    'baraustáramos': (['ba', 'raus', 'tá', 'ra', 'mos'],
                      [(['ba', 'raus', 'tá', 'ra', 'mos'], (1, 2))]),
    'baraustáremos': (['ba', 'raus', 'tá', 're', 'mos'],
                      [(['ba', 'raus', 'tá', 're', 'mos'], (1, 2))]),
    'baraustás': (['ba', 'raus', 'tás'], [(['ba', 'raus', 'tás'], (1, 2))]),
    'baraustásemos': (['ba', 'raus', 'tá', 'se', 'mos'],
                      [(['ba', 'raus', 'tá', 'se', 'mos'], (1, 2))]),
    'barausté': (['ba', 'raus', 'té'], [(['ba', 'raus', 'té'], (1, 2))]),
    'baraustéis': (['ba', 'raus', 'téis'], [(['ba', 'raus', 'téis'], (1, 2))]),
    'baraustó': (['ba', 'raus', 'tó'], [(['ba', 'raus', 'tó'], (1, 2))]),
    'barriada': (['ba', 'rria', 'da'], [(['ba', 'rri', 'a', 'da'], (1, 2))]),
    'barriadas': (['ba', 'rria', 'das'], [(['ba', 'rri', 'a', 'das'], (1, 2))]),
    'beduino': (['be', 'dui', 'no'], [(['be', 'du', 'i', 'no'], (1, 2))]),
    'beduinos': (['be', 'dui', 'nos'], [(['be', 'du', 'i', 'nos'], (1, 2))]),
    'bianual': (['bia', 'nual'], [(['bia', 'nu', 'al'], (1, 2))]),
    'bienio': (['bie', 'nio'], [(['bi', 'e', 'nio'], (0, 1))]),
    'bienios': (['bie', 'nios'], [(['bi', 'e', 'nios'], (0, 1))]),
    'bimensual': (['bi', 'men', 'sual'], [(['bi', 'men', 'su', 'al'], (2, 3))]),
    'bisexual': (['bi', 'se', 'xual'], [(['bi', 'se', 'xu', 'al'], (2, 3))]),
    'carruaje': (['ca', 'rrua', 'je'], [(['ca', 'rru', 'a', 'je'], (1, 2))]),
    'carruajes': (['ca', 'rrua', 'jes'], [(['ca', 'rru', 'a', 'jes'], (1, 2))]),
    'cliente': (['clien', 'te'], [(['cli', 'en', 'te'], (0, 1))]),
    'clientes': (['clien', 'tes'], [(['cli', 'en', 'tes'], (0, 1))]),
    'conceptual': (['con', 'cep', 'tual'],
                   [(['con', 'cep', 'tu', 'al'], (2, 3))]),
    'congruencia': (['con', 'gruen', 'cia'],
                    [(['con', 'gru', 'en', 'cia'], (1, 2))]),
    'congruencias': (['con', 'gruen', 'cias'],
                     [(['con', 'gru', 'en', 'cias'], (1, 2))]),
    'congruente': (['con', 'gruen', 'te'],
                   [(['con', 'gru', 'en', 'te'], (1, 2))]),
    'congruentes': (['con', 'gruen', 'tes'],
                    [(['con', 'gru', 'en', 'tes'], (1, 2))]),
    'consensual': (['con', 'sen', 'sual'],
                   [(['con', 'sen', 'su', 'al'], (2, 3))]),
    'contextual': (['con', 'tex', 'tual'],
                   [(['con', 'tex', 'tu', 'al'], (2, 3))]),
    'contractual': (['con', 'trac', 'tual'],
                    [(['con', 'trac', 'tu', 'al'], (2, 3))]),
    'conventual': (['con', 'ven', 'tual'],
                   [(['con', 'ven', 'tu', 'al'], (2, 3))]),
    'criada': (['cria', 'da'], [(['cri', 'a', 'da'], (0, 1))]),
    'criado': (['cria', 'do'], [(['cri', 'a', 'do'], (0, 1))]),
    'criar': (['criar'], [(['cri', 'ar'], (0, 1))]),
    'criamos': (['cria', 'mos'], [(['cri', 'a', 'mos'], (0, 1))]),
    'crió': (['crió'], [(['cri', 'ó'], (0, 1))]),
    'criadilla': (['cria', 'di', 'lla'], [(['cri', 'a', 'di', 'lla'], (0, 1))]),
    'criadillas': (['cria', 'di', 'llas'],
                   [(['cri', 'a', 'di', 'llas'], (0, 1))]),
    'criatura': (['cria', 'tu', 'ra'], [(['cri', 'a', 'tu', 'ra'], (0, 1))]),
    'criaturas': (['cria', 'tu', 'ras'], [(['cri', 'a', 'tu', 'ras'], (0, 1))]),
    'criollismo': (['crio', 'llis', 'mo'],
                   [(['cri', 'o', 'llis', 'mo'], (0, 1))]),
    'criollismos': (['crio', 'llis', 'mos'],
                    [(['cri', 'o', 'llis', 'mos'], (0, 1))]),
    'criollo': (['crio', 'llo'], [(['cri', 'o', 'llo'], (0, 1))]),
    'criollos': (['crio', 'llos'], [(['cri', 'o', 'llos'], (0, 1))]),
    'cruel': (['cruel'], [(['cru', 'el'], (0, 1))]),
    'crueldad': (['cruel', 'dad'], [(['cru', 'el', 'dad'], (0, 1))]),
    'crueldades': (['cruel', 'da', 'des'],
                   [(['cru', 'el', 'da', 'des'], (0, 1))]),
    'crueles': (['crue', 'les'], [(['cru', 'e', 'les'], (0, 1))]),
    'cruento': (['cruen', 'to'], [(['cru', 'en', 'to'], (0, 1))]),
    'cruentos': (['cruen', 'tos'], [(['cru', 'en', 'tos'], (0, 1))]),
    'desainaba': (['de', 'sai', 'na', 'ba'],
                  [(['de', 'sa', 'i', 'na', 'ba'], (1, 2))]),
    'desainabais': (['de', 'sai', 'na', 'bais'],
                    [(['de', 'sa', 'i', 'na', 'bais'], (1, 2))]),
    'desainaban': (['de', 'sai', 'na', 'ban'],
                   [(['de', 'sa', 'i', 'na', 'ban'], (1, 2))]),
    'desainabas': (['de', 'sai', 'na', 'bas'],
                   [(['de', 'sa', 'i', 'na', 'bas'], (1, 2))]),
    'desainad': (['de', 'sai', 'nad'], [(['de', 'sa', 'i', 'nad'], (1, 2))]),
    'desainado': (['de', 'sai', 'na', 'do'],
                  [(['de', 'sa', 'i', 'na', 'do'], (1, 2))]),
    'desainamos': (['de', 'sai', 'na', 'mos'],
                   [(['de', 'sa', 'i', 'na', 'mos'], (1, 2))]),
    'desainando': (['de', 'sai', 'nan', 'do'],
                   [(['de', 'sa', 'i', 'nan', 'do'], (1, 2))]),
    'desainar': (['de', 'sai', 'nar'], [(['de', 'sa', 'i', 'nar'], (1, 2))]),
    'desainara': (['de', 'sai', 'na', 'ra'],
                  [(['de', 'sa', 'i', 'na', 'ra'], (1, 2))]),
    'desainarais': (['de', 'sai', 'na', 'rais'],
                    [(['de', 'sa', 'i', 'na', 'rais'], (1, 2))]),
    'desainaran': (['de', 'sai', 'na', 'ran'],
                   [(['de', 'sa', 'i', 'na', 'ran'], (1, 2))]),
    'desainaras': (['de', 'sai', 'na', 'ras'],
                   [(['de', 'sa', 'i', 'na', 'ras'], (1, 2))]),
    'desainare': (['de', 'sai', 'na', 're'],
                  [(['de', 'sa', 'i', 'na', 're'], (1, 2))]),
    'desainareis': (['de', 'sai', 'na', 'reis'],
                    [(['de', 'sa', 'i', 'na', 'reis'], (1, 2))]),
    'desainaremos': (['de', 'sai', 'na', 're', 'mos'],
                     [(['de', 'sa', 'i', 'na', 're', 'mos'], (1, 2))]),
    'desainaren': (['de', 'sai', 'na', 'ren'],
                   [(['de', 'sa', 'i', 'na', 'ren'], (1, 2))]),
    'desainares': (['de', 'sai', 'na', 'res'],
                   [(['de', 'sa', 'i', 'na', 'res'], (1, 2))]),
    'desainaron': (['de', 'sai', 'na', 'ron'],
                   [(['de', 'sa', 'i', 'na', 'ron'], (1, 2))]),
    'desainará': (['de', 'sai', 'na', 'rá'],
                  [(['de', 'sa', 'i', 'na', 'rá'], (1, 2))]),
    'desainarán': (['de', 'sai', 'na', 'rán'],
                   [(['de', 'sa', 'i', 'na', 'rán'], (1, 2))]),
    'desainarás': (['de', 'sai', 'na', 'rás'],
                   [(['de', 'sa', 'i', 'na', 'rás'], (1, 2))]),
    'desainaré': (['de', 'sai', 'na', 'ré'],
                  [(['de', 'sa', 'i', 'na', 'ré'], (1, 2))]),
    'desainaréis': (['de', 'sai', 'na', 'réis'],
                    [(['de', 'sa', 'i', 'na', 'réis'], (1, 2))]),
    'desainaría': (['de', 'sai', 'na', 'rí', 'a'],
                   [(['de', 'sa', 'i', 'na', 'rí', 'a'], (1, 2))]),
    'desainaríais': (['de', 'sai', 'na', 'rí', 'ais'],
                     [(['de', 'sa', 'i', 'na', 'rí', 'ais'], (1, 2))]),
    'desainaríamos': (['de', 'sai', 'na', 'rí', 'a', 'mos'],
                      [(['de', 'sa', 'i', 'na', 'rí', 'a', 'mos'], (1, 2))]),
    'desainarían': (['de', 'sai', 'na', 'rí', 'an'],
                    [(['de', 'sa', 'i', 'na', 'rí', 'an'], (1, 2))]),
    'desainarías': (['de', 'sai', 'na', 'rí', 'as'],
                    [(['de', 'sa', 'i', 'na', 'rí', 'as'], (1, 2))]),
    'desainase': (['de', 'sai', 'na', 'se'],
                  [(['de', 'sa', 'i', 'na', 'se'], (1, 2))]),
    'desainaseis': (['de', 'sai', 'na', 'seis'],
                    [(['de', 'sa', 'i', 'na', 'seis'], (1, 2))]),
    'desainasen': (['de', 'sai', 'na', 'sen'],
                   [(['de', 'sa', 'i', 'na', 'sen'], (1, 2))]),
    'desainases': (['de', 'sai', 'na', 'ses'],
                   [(['de', 'sa', 'i', 'na', 'ses'], (1, 2))]),
    'desainaste': (['de', 'sai', 'nas', 'te'],
                   [(['de', 'sa', 'i', 'nas', 'te'], (1, 2))]),
    'desainasteis': (['de', 'sai', 'nas', 'teis'],
                     [(['de', 'sa', 'i', 'nas', 'teis'], (1, 2))]),
    'desainemos': (['de', 'sai', 'ne', 'mos'],
                   [(['de', 'sa', 'i', 'ne', 'mos'], (1, 2))]),
    'desainá': (['de', 'sai', 'ná'], [(['de', 'sa', 'i', 'ná'], (1, 2))]),
    'desainábamos': (['de', 'sai', 'ná', 'ba', 'mos'],
                     [(['de', 'sa', 'i', 'ná', 'ba', 'mos'], (1, 2))]),
    'desaináis': (['de', 'sai', 'náis'], [(['de', 'sa', 'i', 'náis'], (1, 2))]),
    'desaináramos': (['de', 'sai', 'ná', 'ra', 'mos'],
                     [(['de', 'sa', 'i', 'ná', 'ra', 'mos'], (1, 2))]),
    'desaináremos': (['de', 'sai', 'ná', 're', 'mos'],
                     [(['de', 'sa', 'i', 'ná', 're', 'mos'], (1, 2))]),
    'desainás': (['de', 'sai', 'nás'], [(['de', 'sa', 'i', 'nás'], (1, 2))]),
    'desainásemos': (['de', 'sai', 'ná', 'se', 'mos'],
                     [(['de', 'sa', 'i', 'ná', 'se', 'mos'], (1, 2))]),
    'desainé': (['de', 'sai', 'né'], [(['de', 'sa', 'i', 'né'], (1, 2))]),
    'desainéis': (['de', 'sai', 'néis'], [(['de', 'sa', 'i', 'néis'], (1, 2))]),
    'desainó': (['de', 'sai', 'nó'], [(['de', 'sa', 'i', 'nó'], (1, 2))]),
    'desoiremos': (['de', 'soi', 're', 'mos'],
                   [(['de', 'so', 'i', 're', 'mos'], (1, 2))]),
    'desoirá': (['de', 'soi', 'rá'], [(['de', 'so', 'i', 'rá'], (1, 2))]),
    'desoirán': (['de', 'soi', 'rán'], [(['de', 'so', 'i', 'rán'], (1, 2))]),
    'desoirás': (['de', 'soi', 'rás'], [(['de', 'so', 'i', 'rás'], (1, 2))]),
    'desoiré': (['de', 'soi', 'ré'], [(['de', 'so', 'i', 'ré'], (1, 2))]),
    'desoiréis': (['de', 'soi', 'réis'], [(['de', 'so', 'i', 'réis'], (1, 2))]),
    'desoiría': (['de', 'soi', 'rí', 'a'],
                 [(['de', 'so', 'i', 'rí', 'a'], (1, 2))]),
    'desoiríais': (['de', 'soi', 'rí', 'ais'],
                   [(['de', 'so', 'i', 'rí', 'ais'], (1, 2))]),
    'desoiríamos': (['de', 'soi', 'rí', 'a', 'mos'],
                    [(['de', 'so', 'i', 'rí', 'a', 'mos'], (1, 2))]),
    'desoirían': (['de', 'soi', 'rí', 'an'],
                  [(['de', 'so', 'i', 'rí', 'an'], (1, 2))]),
    'desoirías': (['de', 'soi', 'rí', 'as'],
                  [(['de', 'so', 'i', 'rí', 'as'], (1, 2))]),
    'desraicemos': (['de', 'srai', 'ce', 'mos'],
                    [(['des', 'ra', 'i', 'ce', 'mos'], (1, 2))]),
    'desraicé': (['de', 'srai', 'cé'], [(['des', 'ra', 'i', 'cé'], (1, 2))]),
    'desraicéis': (['de', 'srai', 'céis'],
                   [(['des', 'ra', 'i', 'céis'], (1, 2))]),
    'desraizaba': (['de', 'srai', 'za', 'ba'],
                   [(['des', 'ra', 'i', 'za', 'ba'], (1, 2))]),
    'desraizabais': (['de', 'srai', 'za', 'bais'],
                     [(['des', 'ra', 'i', 'za', 'bais'], (1, 2))]),
    'desraizaban': (['de', 'srai', 'za', 'ban'],
                    [(['des', 'ra', 'i', 'za', 'ban'], (1, 2))]),
    'desraizabas': (['de', 'srai', 'za', 'bas'],
                    [(['des', 'ra', 'i', 'za', 'bas'], (1, 2))]),
    'desraizad': (['de', 'srai', 'zad'], [(['des', 'ra', 'i', 'zad'], (1, 2))]),
    'desraizado': (['de', 'srai', 'za', 'do'],
                   [(['des', 'ra', 'i', 'za', 'do'], (1, 2))]),
    'desraizamos': (['de', 'srai', 'za', 'mos'],
                    [(['des', 'ra', 'i', 'za', 'mos'], (1, 2))]),
    'desraizando': (['de', 'srai', 'zan', 'do'],
                    [(['des', 'ra', 'i', 'zan', 'do'], (1, 2))]),
    'desraizar': (['de', 'srai', 'zar'], [(['des', 'ra', 'i', 'zar'], (1, 2))]),
    'desraizara': (['de', 'srai', 'za', 'ra'],
                   [(['des', 'ra', 'i', 'za', 'ra'], (1, 2))]),
    'desraizarais': (['de', 'srai', 'za', 'rais'],
                     [(['des', 'ra', 'i', 'za', 'rais'], (1, 2))]),
    'desraizaran': (['de', 'srai', 'za', 'ran'],
                    [(['des', 'ra', 'i', 'za', 'ran'], (1, 2))]),
    'desraizaras': (['de', 'srai', 'za', 'ras'],
                    [(['des', 'ra', 'i', 'za', 'ras'], (1, 2))]),
    'desraizare': (['de', 'srai', 'za', 're'],
                   [(['des', 'ra', 'i', 'za', 're'], (1, 2))]),
    'desraizareis': (['de', 'srai', 'za', 'reis'],
                     [(['des', 'ra', 'i', 'za', 'reis'], (1, 2))]),
    'desraizaremos': (['de', 'srai', 'za', 're', 'mos'],
                      [(['des', 'ra', 'i', 'za', 're', 'mos'], (1, 2))]),
    'desraizaren': (['de', 'srai', 'za', 'ren'],
                    [(['des', 'ra', 'i', 'za', 'ren'], (1, 2))]),
    'desraizares': (['de', 'srai', 'za', 'res'],
                    [(['des', 'ra', 'i', 'za', 'res'], (1, 2))]),
    'desraizaron': (['de', 'srai', 'za', 'ron'],
                    [(['des', 'ra', 'i', 'za', 'ron'], (1, 2))]),
    'desraizará': (['de', 'srai', 'za', 'rá'],
                   [(['des', 'ra', 'i', 'za', 'rá'], (1, 2))]),
    'desraizarán': (['de', 'srai', 'za', 'rán'],
                    [(['des', 'ra', 'i', 'za', 'rán'], (1, 2))]),
    'desraizarás': (['de', 'srai', 'za', 'rás'],
                    [(['des', 'ra', 'i', 'za', 'rás'], (1, 2))]),
    'desraizaré': (['de', 'srai', 'za', 'ré'],
                   [(['des', 'ra', 'i', 'za', 'ré'], (1, 2))]),
    'desraizaréis': (['de', 'srai', 'za', 'réis'],
                     [(['des', 'ra', 'i', 'za', 'réis'], (1, 2))]),
    'desraizaría': (['de', 'srai', 'za', 'rí', 'a'],
                    [(['des', 'ra', 'i', 'za', 'rí', 'a'], (1, 2))]),
    'desraizaríais': (['de', 'srai', 'za', 'rí', 'ais'],
                      [(['des', 'ra', 'i', 'za', 'rí', 'ais'], (1, 2))]),
    'desraizaríamos': (['de', 'srai', 'za', 'rí', 'a', 'mos'],
                       [(['des', 'ra', 'i', 'za', 'rí', 'a', 'mos'], (1, 2))]),
    'desraizarían': (['de', 'srai', 'za', 'rí', 'an'],
                     [(['des', 'ra', 'i', 'za', 'rí', 'an'], (1, 2))]),
    'desraizarías': (['de', 'srai', 'za', 'rí', 'as'],
                     [(['des', 'ra', 'i', 'za', 'rí', 'as'], (1, 2))]),
    'desraizase': (['de', 'srai', 'za', 'se'],
                   [(['des', 'ra', 'i', 'za', 'se'], (1, 2))]),
    'desraizaseis': (['de', 'srai', 'za', 'seis'],
                     [(['des', 'ra', 'i', 'za', 'seis'], (1, 2))]),
    'desraizasen': (['de', 'srai', 'za', 'sen'],
                    [(['des', 'ra', 'i', 'za', 'sen'], (1, 2))]),
    'desraizases': (['de', 'srai', 'za', 'ses'],
                    [(['des', 'ra', 'i', 'za', 'ses'], (1, 2))]),
    'desraizaste': (['de', 'srai', 'zas', 'te'],
                    [(['des', 'ra', 'i', 'zas', 'te'], (1, 2))]),
    'desraizasteis': (['de', 'srai', 'zas', 'teis'],
                      [(['des', 'ra', 'i', 'zas', 'teis'], (1, 2))]),
    'desraizá': (['de', 'srai', 'zá'], [(['des', 'ra', 'i', 'zá'], (1, 2))]),
    'desraizábamos': (['de', 'srai', 'zá', 'ba', 'mos'],
                      [(['des', 'ra', 'i', 'zá', 'ba', 'mos'], (1, 2))]),
    'desraizáis': (['de', 'srai', 'záis'],
                   [(['des', 'ra', 'i', 'záis'], (1, 2))]),
    'desraizáramos': (['de', 'srai', 'zá', 'ra', 'mos'],
                      [(['des', 'ra', 'i', 'zá', 'ra', 'mos'], (1, 2))]),
    'desraizáremos': (['de', 'srai', 'zá', 're', 'mos'],
                      [(['des', 'ra', 'i', 'zá', 're', 'mos'], (1, 2))]),
    'desraizás': (['de', 'srai', 'zás'], [(['des', 'ra', 'i', 'zás'], (1, 2))]),
    'desraizásemos': (['de', 'srai', 'zá', 'se', 'mos'],
                      [(['des', 'ra', 'i', 'zá', 'se', 'mos'], (1, 2))]),
    'desraizó': (['de', 'srai', 'zó'], [(['des', 'ra', 'i', 'zó'], (1, 2))]),
    'diablo': (['dia', 'blo'], [(['di', 'a', 'blo'], (0, 1))]),
    'diablos': (['dia', 'blos'], [(['di', 'a', 'blos'], (0, 1))]),
    'dial': (['dial'], [(['di', 'al'], (0, 1))]),
    'diales': (['dia', 'les'], [(['di', 'a', 'les'], (0, 1))]),
    'diamante': (['dia', 'man', 'te'], [(['di', 'a', 'man', 'te'], (0, 1))]),
    'diamantes': (['dia', 'man', 'tes'], [(['di', 'a', 'man', 'tes'], (0, 1))]),
    'diana': (['dia', 'na'], [(['di', 'a', 'na'], (0, 1))]),
    'dianas': (['dia', 'nas'], [(['di', 'a', 'nas'], (0, 1))]),
    'diario': (['dia', 'rio'], [(['di', 'a', 'rio'], (0, 1))]),
    'diarios': (['dia', 'rios'], [(['di', 'a', 'rios'], (0, 1))]),
    'diurno': (['diur', 'no'], [(['di', 'ur', 'no'], (0, 1))]),
    'diurnos': (['diur', 'nos'], [(['di', 'ur', 'nos'], (0, 1))]),
    'diálogo': (['diá', 'lo', 'go'], [(['di', 'á', 'lo', 'go'], (0, 1))]),
    'diálogos': (['diá', 'lo', 'gos'], [(['di', 'á', 'lo', 'gos'], (0, 1))]),
    'diámetro': (['diá', 'me', 'tro'], [(['di', 'á', 'me', 'tro'], (0, 1))]),
    'diámetros': (['diá', 'me', 'tros'], [(['di', 'á', 'me', 'tros'], (0, 1))]),
    'druinismo': (['drui', 'nis', 'mo'], [(['dru', 'i', 'nis', 'mo'], (0, 1))]),
    'druinismos': (['drui', 'nis', 'mos'],
                   [(['dru', 'i', 'nis', 'mos'], (0, 1))]),
    'druídico': (['druí', 'di', 'co'], [(['dru', 'í', 'di', 'co'], (0, 1))]),
    'druídicos': (['druí', 'di', 'cos'], [(['dru', 'í', 'di', 'cos'], (0, 1))]),
    'dual': (['dual'], [(['du', 'al'], (0, 1))]),
    'embairemos': (['em', 'bai', 're', 'mos'],
                   [(['em', 'ba', 'i', 're', 'mos'], (1, 2))]),
    'embairá': (['em', 'bai', 'rá'], [(['em', 'ba', 'i', 'rá'], (1, 2))]),
    'embairán': (['em', 'bai', 'rán'], [(['em', 'ba', 'i', 'rán'], (1, 2))]),
    'embairás': (['em', 'bai', 'rás'], [(['em', 'ba', 'i', 'rás'], (1, 2))]),
    'embairé': (['em', 'bai', 'ré'], [(['em', 'ba', 'i', 'ré'], (1, 2))]),
    'embairéis': (['em', 'bai', 'réis'], [(['em', 'ba', 'i', 'réis'], (1, 2))]),
    'embairía': (['em', 'bai', 'rí', 'a'],
                 [(['em', 'ba', 'i', 'rí', 'a'], (1, 2))]),
    'embairíais': (['em', 'bai', 'rí', 'ais'],
                   [(['em', 'ba', 'i', 'rí', 'ais'], (1, 2))]),
    'embairíamos': (['em', 'bai', 'rí', 'a', 'mos'],
                    [(['em', 'ba', 'i', 'rí', 'a', 'mos'], (1, 2))]),
    'embairían': (['em', 'bai', 'rí', 'an'],
                  [(['em', 'ba', 'i', 'rí', 'an'], (1, 2))]),
    'embairías': (['em', 'bai', 'rí', 'as'],
                  [(['em', 'ba', 'i', 'rí', 'as'], (1, 2))]),
    'embriones': (['em', 'brio', 'nes'], [(['em', 'bri', 'o', 'nes'], (1, 2))]),
    'embrión': (['em', 'brión'], [(['em', 'bri', 'ón'], (1, 2))]),
    'enraicemos': (['e', 'nrai', 'ce', 'mos'],
                   [(['en', 'rai', 'ce', 'mos'], (1, 2))]),
    'enraicé': (['e', 'nrai', 'cé'], [(['en', 'rai', 'cé'], (1, 2))]),
    'enraicéis': (['e', 'nrai', 'céis'], [(['en', 'rai', 'céis'], (1, 2))]),
    'enraizaba': (['e', 'nrai', 'za', 'ba'],
                  [(['en', 'ra', 'i', 'za', 'ba'], (1, 2))]),
    'enraizabais': (['e', 'nrai', 'za', 'bais'],
                    [(['en', 'ra', 'i', 'za', 'bais'], (1, 2))]),
    'enraizaban': (['e', 'nrai', 'za', 'ban'],
                   [(['en', 'ra', 'i', 'za', 'ban'], (1, 2))]),
    'enraizabas': (['e', 'nrai', 'za', 'bas'],
                   [(['en', 'ra', 'i', 'za', 'bas'], (1, 2))]),
    'enraizad': (['e', 'nrai', 'zad'], [(['en', 'ra', 'i', 'zad'], (1, 2))]),
    'enraizado': (['e', 'nrai', 'za', 'do'],
                  [(['en', 'ra', 'i', 'za', 'do'], (1, 2))]),
    'enraizamos': (['e', 'nrai', 'za', 'mos'],
                   [(['en', 'ra', 'i', 'za', 'mos'], (1, 2))]),
    'enraizando': (['e', 'nrai', 'zan', 'do'],
                   [(['en', 'ra', 'i', 'zan', 'do'], (1, 2))]),
    'enraizar': (['e', 'nrai', 'zar'], [(['en', 'ra', 'i', 'zar'], (1, 2))]),
    'enraizara': (['e', 'nrai', 'za', 'ra'],
                  [(['en', 'ra', 'i', 'za', 'ra'], (1, 2))]),
    'enraizarais': (['e', 'nrai', 'za', 'rais'],
                    [(['en', 'ra', 'i', 'za', 'rais'], (1, 2))]),
    'enraizaran': (['e', 'nrai', 'za', 'ran'],
                   [(['en', 'ra', 'i', 'za', 'ran'], (1, 2))]),
    'enraizaras': (['e', 'nrai', 'za', 'ras'],
                   [(['en', 'ra', 'i', 'za', 'ras'], (1, 2))]),
    'enraizare': (['e', 'nrai', 'za', 're'],
                  [(['en', 'ra', 'i', 'za', 're'], (1, 2))]),
    'enraizareis': (['e', 'nrai', 'za', 'reis'],
                    [(['en', 'ra', 'i', 'za', 'reis'], (1, 2))]),
    'enraizaremos': (['e', 'nrai', 'za', 're', 'mos'],
                     [(['en', 'ra', 'i', 'za', 're', 'mos'], (1, 2))]),
    'enraizaren': (['e', 'nrai', 'za', 'ren'],
                   [(['en', 'ra', 'i', 'za', 'ren'], (1, 2))]),
    'enraizares': (['e', 'nrai', 'za', 'res'],
                   [(['en', 'ra', 'i', 'za', 'res'], (1, 2))]),
    'enraizaron': (['e', 'nrai', 'za', 'ron'],
                   [(['en', 'ra', 'i', 'za', 'ron'], (1, 2))]),
    'enraizará': (['e', 'nrai', 'za', 'rá'],
                  [(['en', 'ra', 'i', 'za', 'rá'], (1, 2))]),
    'enraizarán': (['e', 'nrai', 'za', 'rán'],
                   [(['en', 'ra', 'i', 'za', 'rán'], (1, 2))]),
    'enraizarás': (['e', 'nrai', 'za', 'rás'],
                   [(['en', 'ra', 'i', 'za', 'rás'], (1, 2))]),
    'enraizaré': (['e', 'nrai', 'za', 'ré'],
                  [(['en', 'ra', 'i', 'za', 'ré'], (1, 2))]),
    'enraizaréis': (['e', 'nrai', 'za', 'réis'],
                    [(['en', 'ra', 'i', 'za', 'réis'], (1, 2))]),
    'enraizaría': (['e', 'nrai', 'za', 'rí', 'a'],
                   [(['en', 'ra', 'i', 'za', 'rí', 'a'], (1, 2))]),
    'enraizaríais': (['e', 'nrai', 'za', 'rí', 'ais'],
                     [(['en', 'ra', 'i', 'za', 'rí', 'ais'], (1, 2))]),
    'enraizaríamos': (['e', 'nrai', 'za', 'rí', 'a', 'mos'],
                      [(['en', 'ra', 'i', 'za', 'rí', 'a', 'mos'], (1, 2))]),
    'enraizarían': (['e', 'nrai', 'za', 'rí', 'an'],
                    [(['en', 'ra', 'i', 'za', 'rí', 'an'], (1, 2))]),
    'enraizarías': (['e', 'nrai', 'za', 'rí', 'as'],
                    [(['en', 'ra', 'i', 'za', 'rí', 'as'], (1, 2))]),
    'enraizase': (['e', 'nrai', 'za', 'se'],
                  [(['en', 'ra', 'i', 'za', 'se'], (1, 2))]),
    'enraizaseis': (['e', 'nrai', 'za', 'seis'],
                    [(['en', 'ra', 'i', 'za', 'seis'], (1, 2))]),
    'enraizasen': (['e', 'nrai', 'za', 'sen'],
                   [(['en', 'ra', 'i', 'za', 'sen'], (1, 2))]),
    'enraizases': (['e', 'nrai', 'za', 'ses'],
                   [(['en', 'ra', 'i', 'za', 'ses'], (1, 2))]),
    'enraizaste': (['e', 'nrai', 'zas', 'te'],
                   [(['en', 'ra', 'i', 'zas', 'te'], (1, 2))]),
    'enraizasteis': (['e', 'nrai', 'zas', 'teis'],
                     [(['en', 'ra', 'i', 'zas', 'teis'], (1, 2))]),
    'enraizá': (['e', 'nrai', 'zá'], [(['en', 'ra', 'i', 'zá'], (1, 2))]),
    'enraizábamos': (['e', 'nrai', 'zá', 'ba', 'mos'],
                     [(['en', 'ra', 'i', 'zá', 'ba', 'mos'], (1, 2))]),
    'enraizáis': (['e', 'nrai', 'záis'], [(['en', 'ra', 'i', 'záis'], (1, 2))]),
    'enraizáramos': (['e', 'nrai', 'zá', 'ra', 'mos'],
                     [(['en', 'ra', 'i', 'zá', 'ra', 'mos'], (1, 2))]),
    'enraizáremos': (['e', 'nrai', 'zá', 're', 'mos'],
                     [(['en', 'ra', 'i', 'zá', 're', 'mos'], (1, 2))]),
    'enraizás': (['e', 'nrai', 'zás'], [(['en', 'ra', 'i', 'zás'], (1, 2))]),
    'enraizásemos': (['e', 'nrai', 'zá', 'se', 'mos'],
                     [(['en', 'ra', 'i', 'zá', 'se', 'mos'], (1, 2))]),
    'enraizó': (['e', 'nrai', 'zó'], [(['en', 'ra', 'i', 'zó'], (1, 2))]),
    'entreoiremos': (['en', 'tre', 'oi', 're', 'mos'],
                     [(['en', 'tre', 'o', 'i', 're', 'mos'], (2, 3))]),
    'entreoirá': (['en', 'tre', 'oi', 'rá'],
                  [(['en', 'tre', 'o', 'i', 'rá'], (2, 3))]),
    'entreoirán': (['en', 'tre', 'oi', 'rán'],
                   [(['en', 'tre', 'o', 'i', 'rán'], (2, 3))]),
    'entreoirás': (['en', 'tre', 'oi', 'rás'],
                   [(['en', 'tre', 'o', 'i', 'rás'], (2, 3))]),
    'entreoiré': (['en', 'tre', 'oi', 'ré'],
                  [(['en', 'tre', 'o', 'i', 'ré'], (2, 3))]),
    'entreoiréis': (['en', 'tre', 'oi', 'réis'],
                    [(['en', 'tre', 'o', 'i', 'réis'], (2, 3))]),
    'entreoiría': (['en', 'tre', 'oi', 'rí', 'a'],
                   [(['en', 'tre', 'o', 'i', 'rí', 'a'], (2, 3))]),
    'entreoiríais': (['en', 'tre', 'oi', 'rí', 'ais'],
                     [(['en', 'tre', 'o', 'i', 'rí', 'ais'], (2, 3))]),
    'entreoiríamos': (['en', 'tre', 'oi', 'rí', 'a', 'mos'],
                      [(['en', 'tre', 'o', 'i', 'rí', 'a', 'mos'], (2, 3))]),
    'entreoirían': (['en', 'tre', 'oi', 'rí', 'an'],
                    [(['en', 'tre', 'o', 'i', 'rí', 'an'], (2, 3))]),
    'entreoirías': (['en', 'tre', 'oi', 'rí', 'as'],
                    [(['en', 'tre', 'o', 'i', 'rí', 'as'], (2, 3))]),
    'espiritual': (['es', 'pi', 'ri', 'tual'],
                   [(['es', 'pi', 'ri', 'tu', 'al'], (3, 4))]),
    'eventual': (['e', 'ven', 'tual'], [(['e', 'ven', 'tu', 'al'], (2, 3))]),
    'frialdad': (['frial', 'dad'], [(['fri', 'al', 'dad'], (0, 1))]),
    'frialdades': (['frial', 'da', 'des'],
                   [(['fri', 'al', 'da', 'des'], (0, 1))]),
    'friolento': (['frio', 'len', 'to'], [(['fri', 'o', 'len', 'to'], (0, 1))]),
    'friolentos': (['frio', 'len', 'tos'],
                   [(['fri', 'o', 'len', 'tos'], (0, 1))]),
    'friolera': (['frio', 'le', 'ra'], [(['fri', 'o', 'le', 'ra'], (0, 1))]),
    'frioleras': (['frio', 'le', 'ras'], [(['fri', 'o', 'le', 'ras'], (0, 1))]),
    'friático': (['friá', 'ti', 'co'], [(['fri', 'á', 'ti', 'co'], (0, 1))]),
    'friáticos': (['friá', 'ti', 'cos'], [(['fri', 'á', 'ti', 'cos'], (0, 1))]),
    'gradual': (['gra', 'dual'], [(['gra', 'du', 'al'], (1, 2))]),
    'gratuito': (['gra', 'tui', 'to'], [(['gra', 'tu', 'i', 'to'], (1, 2))]),
    'gratuitos': (['gra', 'tui', 'tos'], [(['gra', 'tu', 'i', 'tos'], (1, 2))]),
    'guiones': (['guio', 'nes'], [(['gui', 'o', 'nes'], (0, 1))]),
    'guión': (['guión'], [(['gui', 'ón'], (0, 1))]),
    'habitual': (['ha', 'bi', 'tual'], [(['ha', 'bi', 'tu', 'al'], (2, 3))]),
    'hiato': (['hia', 'to'], [(['hi', 'a', 'to'], (0, 1))]),
    'hiatos': (['hia', 'tos'], [(['hi', 'a', 'tos'], (0, 1))]),
    'homosexual': (['ho', 'mo', 'se', 'xual'],
                   [(['ho', 'mo', 'se', 'xu', 'al'], (3, 4))]),
    'inactual': (['i', 'nac', 'tual'], [(['i', 'nac', 'tu', 'al'], (2, 3))]),
    'incestuoso': (['in', 'ces', 'tuo', 'so'],
                   [(['in', 'ces', 'tu', 'o', 'so'], (2, 3))]),
    'incestuosos': (['in', 'ces', 'tuo', 'sos'],
                    [(['in', 'ces', 'tu', 'o', 'sos'], (2, 3))]),
    'incongruencia': (['in', 'con', 'gruen', 'cia'],
                      [(['in', 'con', 'gru', 'en', 'cia'], (2, 3))]),
    'incongruencias': (['in', 'con', 'gruen', 'cias'],
                       [(['in', 'con', 'gru', 'en', 'cias'], (2, 3))]),
    'incongruente': (['in', 'con', 'gruen', 'te'],
                     [(['in', 'con', 'gru', 'en', 'te'], (2, 3))]),
    'incongruentes': (['in', 'con', 'gruen', 'tes'],
                      [(['in', 'con', 'gru', 'en', 'tes'], (2, 3))]),
    'incruento': (['in', 'cruen', 'to'], [(['in', 'cru', 'en', 'to'], (1, 2))]),
    'incruentos': (['in', 'cruen', 'tos'],
                   [(['in', 'cru', 'en', 'tos'], (1, 2))]),
    'individual': (['in', 'di', 'vi', 'dual'],
                   [(['in', 'di', 'vi', 'du', 'al'], (3, 4))]),
    'individualmente': (['in', 'di', 'vi', 'dual', 'men', 'te'],
                        [(['in', 'di', 'vi', 'du', 'al', 'men', 'te'],
                          (3, 4))]),
    'intelectual': (['in', 'te', 'lec', 'tual'],
                    [(['in', 'te', 'lec', 'tu', 'al'], (3, 4))]),
    'inusual': (['i', 'nu', 'sual'], [(['i', 'nu', 'su', 'al'], (2, 3))]),
    'inviable': (['in', 'via', 'ble'], [(['in', 'vi', 'a', 'ble'], (1, 2))]),
    'inviables': (['in', 'via', 'bles'], [(['in', 'vi', 'a', 'bles'], (1, 2))]),
    'jesuita': (['je', 'sui', 'ta'], [(['je', 'su', 'i', 'ta'], (1, 2))]),
    'jesuitas': (['je', 'sui', 'tas'], [(['je', 'su', 'i', 'tas'], (1, 2))]),
    'juicio': (['jui', 'cio'], [(['ju', 'i', 'cio'], (0, 1))]),
    'juicios': (['jui', 'cios'], [(['ju', 'i', 'cios'], (0, 1))]),
    'kiosco': (['kios', 'co'], [(['ki', 'os', 'co'], (0, 1))]),
    'kioscos': (['kios', 'cos'], [(['ki', 'os', 'cos'], (0, 1))]),
    'manual': (['ma', 'nual'], [(['ma', 'nu', 'al'], (1, 2))]),
    'maullaba': (['mau', 'lla', 'ba'], [(['ma', 'u', 'lla', 'ba'], (0, 1))]),
    'maullabais': (['mau', 'lla', 'bais'],
                   [(['ma', 'u', 'lla', 'bais'], (0, 1))]),
    'maullaban': (['mau', 'lla', 'ban'], [(['ma', 'u', 'lla', 'ban'], (0, 1))]),
    'maullabas': (['mau', 'lla', 'bas'], [(['ma', 'u', 'lla', 'bas'], (0, 1))]),
    'maullad': (['mau', 'llad'], [(['ma', 'u', 'llad'], (0, 1))]),
    'maulladero': (['mau', 'lla', 'de', 'ro'],
                   [(['mau', 'lla', 'de', 'ro'], (0, 1))]),
    'maullado': (['mau', 'lla', 'do'], [(['ma', 'u', 'lla', 'do'], (0, 1))]),
    'maullamos': (['mau', 'lla', 'mos'], [(['ma', 'u', 'lla', 'mos'], (0, 1))]),
    'maullando': (['mau', 'llan', 'do'], [(['ma', 'u', 'llan', 'do'], (0, 1))]),
    'maullante': (['mau', 'llan', 'te'], [(['mau', 'llan', 'te'], (0, 1))]),
    'maullar': (['mau', 'llar'], [(['ma', 'u', 'llar'], (0, 1))]),
    'maullara': (['mau', 'lla', 'ra'], [(['ma', 'u', 'lla', 'ra'], (0, 1))]),
    'maullarais': (['mau', 'lla', 'rais'],
                   [(['ma', 'u', 'lla', 'rais'], (0, 1))]),
    'maullaran': (['mau', 'lla', 'ran'], [(['ma', 'u', 'lla', 'ran'], (0, 1))]),
    'maullaras': (['mau', 'lla', 'ras'], [(['ma', 'u', 'lla', 'ras'], (0, 1))]),
    'maullare': (['mau', 'lla', 're'], [(['ma', 'u', 'lla', 're'], (0, 1))]),
    'maullareis': (['mau', 'lla', 'reis'],
                   [(['ma', 'u', 'lla', 'reis'], (0, 1))]),
    'maullaremos': (['mau', 'lla', 're', 'mos'],
                    [(['ma', 'u', 'lla', 're', 'mos'], (0, 1))]),
    'maullaren': (['mau', 'lla', 'ren'], [(['ma', 'u', 'lla', 'ren'], (0, 1))]),
    'maullares': (['mau', 'lla', 'res'], [(['ma', 'u', 'lla', 'res'], (0, 1))]),
    'maullaron': (['mau', 'lla', 'ron'], [(['ma', 'u', 'lla', 'ron'], (0, 1))]),
    'maullará': (['mau', 'lla', 'rá'], [(['ma', 'u', 'lla', 'rá'], (0, 1))]),
    'maullarán': (['mau', 'lla', 'rán'], [(['ma', 'u', 'lla', 'rán'], (0, 1))]),
    'maullarás': (['mau', 'lla', 'rás'], [(['ma', 'u', 'lla', 'rás'], (0, 1))]),
    'maullaré': (['mau', 'lla', 'ré'], [(['ma', 'u', 'lla', 'ré'], (0, 1))]),
    'maullaréis': (['mau', 'lla', 'réis'],
                   [(['ma', 'u', 'lla', 'réis'], (0, 1))]),
    'maullaría': (['mau', 'lla', 'rí', 'a'],
                  [(['ma', 'u', 'lla', 'rí', 'a'], (0, 1))]),
    'maullaríais': (['mau', 'lla', 'rí', 'ais'],
                    [(['ma', 'u', 'lla', 'rí', 'ais'], (0, 1))]),
    'maullaríamos': (['mau', 'lla', 'rí', 'a', 'mos'],
                     [(['ma', 'u', 'lla', 'rí', 'a', 'mos'], (0, 1))]),
    'maullarían': (['mau', 'lla', 'rí', 'an'],
                   [(['ma', 'u', 'lla', 'rí', 'an'], (0, 1))]),
    'maullarías': (['mau', 'lla', 'rí', 'as'],
                   [(['ma', 'u', 'lla', 'rí', 'as'], (0, 1))]),
    'maullase': (['mau', 'lla', 'se'], [(['ma', 'u', 'lla', 'se'], (0, 1))]),
    'maullaseis': (['mau', 'lla', 'seis'],
                   [(['ma', 'u', 'lla', 'seis'], (0, 1))]),
    'maullasen': (['mau', 'lla', 'sen'], [(['ma', 'u', 'lla', 'sen'], (0, 1))]),
    'maullases': (['mau', 'lla', 'ses'], [(['ma', 'u', 'lla', 'ses'], (0, 1))]),
    'maullaste': (['mau', 'llas', 'te'], [(['ma', 'u', 'llas', 'te'], (0, 1))]),
    'maullasteis': (['mau', 'llas', 'teis'],
                    [(['ma', 'u', 'llas', 'teis'], (0, 1))]),
    'maullemos': (['mau', 'lle', 'mos'], [(['ma', 'u', 'lle', 'mos'], (0, 1))]),
    'maullido': (['mau', 'lli', 'do'], [(['mau', 'lli', 'do'], (0, 1))]),
    'maullá': (['mau', 'llá'], [(['ma', 'u', 'llá'], (0, 1))]),
    'maullábamos': (['mau', 'llá', 'ba', 'mos'],
                    [(['ma', 'u', 'llá', 'ba', 'mos'], (0, 1))]),
    'maulláis': (['mau', 'lláis'], [(['ma', 'u', 'lláis'], (0, 1))]),
    'maulláramos': (['mau', 'llá', 'ra', 'mos'],
                    [(['ma', 'u', 'llá', 'ra', 'mos'], (0, 1))]),
    'maulláremos': (['mau', 'llá', 're', 'mos'],
                    [(['ma', 'u', 'llá', 're', 'mos'], (0, 1))]),
    'maullás': (['mau', 'llás'], [(['ma', 'u', 'llás'], (0, 1))]),
    'maullásemos': (['mau', 'llá', 'se', 'mos'],
                    [(['ma', 'u', 'llá', 'se', 'mos'], (0, 1))]),
    'maullé': (['mau', 'llé'], [(['ma', 'u', 'llé'], (0, 1))]),
    'maulléis': (['mau', 'lléis'], [(['ma', 'u', 'lléis'], (0, 1))]),
    'maulló': (['mau', 'lló'], [(['ma', 'u', 'lló'], (0, 1))]),
    'mensual': (['men', 'sual'], [(['men', 'su', 'al'], (1, 2))]),
    'miasma': (['mias', 'ma'], [(['mi', 'as', 'ma'], (0, 1))]),
    'miasmas': (['mias', 'mas'], [(['mi', 'as', 'mas'], (0, 1))]),
    'oiremos': (['oi', 're', 'mos'], [(['o', 'i', 're', 'mos'], (0, 1))]),
    'oirá': (['oi', 'rá'], [(['o', 'i', 'rá'], (0, 1))]),
    'oirán': (['oi', 'rán'], [(['o', 'i', 'rán'], (0, 1))]),
    'oirás': (['oi', 'rás'], [(['o', 'i', 'rás'], (0, 1))]),
    'oiré': (['oi', 'ré'], [(['o', 'i', 'ré'], (0, 1))]),
    'oiréis': (['oi', 'réis'], [(['o', 'i', 'réis'], (0, 1))]),
    'oiría': (['oi', 'rí', 'a'], [(['o', 'i', 'rí', 'a'], (0, 1))]),
    'oiríais': (['oi', 'rí', 'ais'], [(['o', 'i', 'rí', 'ais'], (0, 1))]),
    'oiríamos': (['oi', 'rí', 'a', 'mos'],
                 [(['o', 'i', 'rí', 'a', 'mos'], (0, 1))]),
    'oirían': (['oi', 'rí', 'an'], [(['o', 'i', 'rí', 'an'], (0, 1))]),
    'oirías': (['oi', 'rí', 'as'], [(['o', 'i', 'rí', 'as'], (0, 1))]),
    'oriundo': (['o', 'riun', 'do'], [(['o', 'ri', 'un', 'do'], (1, 2))]),
    'oriundos': (['o', 'riun', 'dos'], [(['o', 'ri', 'un', 'dos'], (1, 2))]),
    'pianista': (['pia', 'nis', 'ta'], [(['pi', 'a', 'nis', 'ta'], (0, 1))]),
    'pianistas': (['pia', 'nis', 'tas'], [(['pi', 'a', 'nis', 'tas'], (0, 1))]),
    'piano': (['pia', 'no'], [(['pi', 'a', 'no'], (0, 1))]),
    'pianola': (['pia', 'no', 'la'], [(['pi', 'a', 'no', 'la'], (0, 1))]),
    'pianolas': (['pia', 'no', 'las'], [(['pi', 'a', 'no', 'las'], (0, 1))]),
    'pianos': (['pia', 'nos'], [(['pi', 'a', 'nos'], (0, 1))]),
    'piara': (['pia', 'ra'], [(['pi', 'a', 'ra'], (0, 1))]),
    'piaras': (['pia', 'ras'], [(['pi', 'a', 'ras'], (0, 1))]),
    'piojera': (['pio', 'je', 'ra'], [(['pi', 'o', 'je', 'ra'], (0, 1))]),
    'piojeras': (['pio', 'je', 'ras'], [(['pi', 'o', 'je', 'ras'], (0, 1))]),
    'piojillo': (['pio', 'ji', 'llo'], [(['pi', 'o', 'ji', 'llo'], (0, 1))]),
    'piojillos': (['pio', 'ji', 'llos'], [(['pi', 'o', 'ji', 'llos'], (0, 1))]),
    'piojo': (['pio', 'jo'], [(['pi', 'o', 'jo'], (0, 1))]),
    'piojos': (['pio', 'jos'], [(['pi', 'o', 'jos'], (0, 1))]),
    'porcentual': (['por', 'cen', 'tual'],
                   [(['por', 'cen', 'tu', 'al'], (2, 3))]),
    'priapismo': (['pria', 'pis', 'mo'], [(['pri', 'a', 'pis', 'mo'], (0, 1))]),
    'priapismos': (['pria', 'pis', 'mos'],
                   [(['pri', 'a', 'pis', 'mos'], (0, 1))]),
    'prior': (['prior'], [(['pri', 'or'], (0, 1))]),
    'priorato': (['prio', 'ra', 'to'], [(['pri', 'o', 'ra', 'to'], (0, 1))]),
    'prioratos': (['prio', 'ra', 'tos'], [(['pri', 'o', 'ra', 'tos'], (0, 1))]),
    'priorazgo': (['prio', 'raz', 'go'], [(['pri', 'o', 'raz', 'go'], (0, 1))]),
    'priorazgos': (['prio', 'raz', 'gos'],
                   [(['pri', 'o', 'raz', 'gos'], (0, 1))]),
    'priores': (['prio', 'res'], [(['pri', 'o', 'res'], (0, 1))]),
    'prioridad': (['prio', 'ri', 'dad'], [(['pri', 'o', 'ri', 'dad'], (0, 1))]),
    'prioridades': (['prio', 'ri', 'da', 'des'],
                    [(['pri', 'o', 'ri', 'da', 'des'], (0, 1))]),
    'puntual': (['pun', 'tual'], [(['pun', 'tu', 'al'], (1, 2))]),
    'quiosco': (['quios', 'co'], [(['qui', 'os', 'co'], (0, 1))]),
    'quioscos': (['quios', 'cos'], [(['qui', 'os', 'cos'], (0, 1))]),
    'riachuelo': (['ria', 'chue', 'lo'], [(['ri', 'a', 'chue', 'lo'], (0, 1))]),
    'riachuelos': (['ria', 'chue', 'los'],
                   [(['ri', 'a', 'chue', 'los'], (0, 1))]),
    'riada': (['ria', 'da'], [(['ri', 'a', 'da'], (0, 1))]),
    'riadas': (['ria', 'das'], [(['ri', 'a', 'das'], (0, 1))]),
    'riel': (['riel'], [(['ri', 'el'], (0, 1))]),
    'rielera': (['rie', 'le', 'ra'], [(['ri', 'e', 'le', 'ra'], (0, 1))]),
    'rieleras': (['rie', 'le', 'ras'], [(['ri', 'e', 'le', 'ras'], (0, 1))]),
    'rieles': (['rie', 'les'], [(['ri', 'e', 'les'], (0, 1))]),
    'ritual': (['ri', 'tual'], [(['ri', 'tu', 'al'], (1, 2))]),
    'ruin': (['ruin'], [(['ru', 'in'], (0, 1))]),
    'ruines': (['rui', 'nes'], [(['ru', 'i', 'nes'], (0, 1))]),
    'sainaba': (['sai', 'na', 'ba'], [(['sa', 'i', 'na', 'ba'], (0, 1))]),
    'sainabais': (['sai', 'na', 'bais'], [(['sa', 'i', 'na', 'bais'], (0, 1))]),
    'sainaban': (['sai', 'na', 'ban'], [(['sa', 'i', 'na', 'ban'], (0, 1))]),
    'sainabas': (['sai', 'na', 'bas'], [(['sa', 'i', 'na', 'bas'], (0, 1))]),
    'sainad': (['sai', 'nad'], [(['sa', 'i', 'nad'], (0, 1))]),
    'sainado': (['sai', 'na', 'do'], [(['sa', 'i', 'na', 'do'], (0, 1))]),
    'sainamos': (['sai', 'na', 'mos'], [(['sa', 'i', 'na', 'mos'], (0, 1))]),
    'sainando': (['sai', 'nan', 'do'], [(['sa', 'i', 'nan', 'do'], (0, 1))]),
    'sainar': (['sai', 'nar'], [(['sa', 'i', 'nar'], (0, 1))]),
    'sainara': (['sai', 'na', 'ra'], [(['sa', 'i', 'na', 'ra'], (0, 1))]),
    'sainarais': (['sai', 'na', 'rais'], [(['sa', 'i', 'na', 'rais'], (0, 1))]),
    'sainaran': (['sai', 'na', 'ran'], [(['sa', 'i', 'na', 'ran'], (0, 1))]),
    'sainaras': (['sai', 'na', 'ras'], [(['sa', 'i', 'na', 'ras'], (0, 1))]),
    'sainare': (['sai', 'na', 're'], [(['sa', 'i', 'na', 're'], (0, 1))]),
    'sainareis': (['sai', 'na', 'reis'], [(['sa', 'i', 'na', 'reis'], (0, 1))]),
    'sainaremos': (['sai', 'na', 're', 'mos'],
                   [(['sa', 'i', 'na', 're', 'mos'], (0, 1))]),
    'sainaren': (['sai', 'na', 'ren'], [(['sa', 'i', 'na', 'ren'], (0, 1))]),
    'sainares': (['sai', 'na', 'res'], [(['sa', 'i', 'na', 'res'], (0, 1))]),
    'sainaron': (['sai', 'na', 'ron'], [(['sa', 'i', 'na', 'ron'], (0, 1))]),
    'sainará': (['sai', 'na', 'rá'], [(['sa', 'i', 'na', 'rá'], (0, 1))]),
    'sainarán': (['sai', 'na', 'rán'], [(['sa', 'i', 'na', 'rán'], (0, 1))]),
    'sainarás': (['sai', 'na', 'rás'], [(['sa', 'i', 'na', 'rás'], (0, 1))]),
    'sainaré': (['sai', 'na', 'ré'], [(['sa', 'i', 'na', 'ré'], (0, 1))]),
    'sainaréis': (['sai', 'na', 'réis'], [(['sa', 'i', 'na', 'réis'], (0, 1))]),
    'sainaría': (['sai', 'na', 'rí', 'a'],
                 [(['sa', 'i', 'na', 'rí', 'a'], (0, 1))]),
    'sainaríais': (['sai', 'na', 'rí', 'ais'],
                   [(['sa', 'i', 'na', 'rí', 'ais'], (0, 1))]),
    'sainaríamos': (['sai', 'na', 'rí', 'a', 'mos'],
                    [(['sa', 'i', 'na', 'rí', 'a', 'mos'], (0, 1))]),
    'sainarían': (['sai', 'na', 'rí', 'an'],
                  [(['sa', 'i', 'na', 'rí', 'an'], (0, 1))]),
    'sainarías': (['sai', 'na', 'rí', 'as'],
                  [(['sa', 'i', 'na', 'rí', 'as'], (0, 1))]),
    'sainase': (['sai', 'na', 'se'], [(['sa', 'i', 'na', 'se'], (0, 1))]),
    'sainaseis': (['sai', 'na', 'seis'], [(['sa', 'i', 'na', 'seis'], (0, 1))]),
    'sainasen': (['sai', 'na', 'sen'], [(['sa', 'i', 'na', 'sen'], (0, 1))]),
    'sainases': (['sai', 'na', 'ses'], [(['sa', 'i', 'na', 'ses'], (0, 1))]),
    'sainaste': (['sai', 'nas', 'te'], [(['sa', 'i', 'nas', 'te'], (0, 1))]),
    'sainasteis': (['sai', 'nas', 'teis'],
                   [(['sa', 'i', 'nas', 'teis'], (0, 1))]),
    'sainemos': (['sai', 'ne', 'mos'], [(['sa', 'i', 'ne', 'mos'], (0, 1))]),
    'sainá': (['sai', 'ná'], [(['sa', 'i', 'ná'], (0, 1))]),
    'sainábamos': (['sai', 'ná', 'ba', 'mos'],
                   [(['sa', 'i', 'ná', 'ba', 'mos'], (0, 1))]),
    'saináis': (['sai', 'náis'], [(['sa', 'i', 'náis'], (0, 1))]),
    'saináramos': (['sai', 'ná', 'ra', 'mos'],
                   [(['sa', 'i', 'ná', 'ra', 'mos'], (0, 1))]),
    'saináremos': (['sai', 'ná', 're', 'mos'],
                   [(['sa', 'i', 'ná', 're', 'mos'], (0, 1))]),
    'sainás': (['sai', 'nás'], [(['sa', 'i', 'nás'], (0, 1))]),
    'sainásemos': (['sai', 'ná', 'se', 'mos'],
                   [(['sa', 'i', 'ná', 'se', 'mos'], (0, 1))]),
    'sainé': (['sai', 'né'], [(['sa', 'i', 'né'], (0, 1))]),
    'sainéis': (['sai', 'néis'], [(['sa', 'i', 'néis'], (0, 1))]),
    'sainó': (['sai', 'nó'], [(['sa', 'i', 'nó'], (0, 1))]),
    'sensual': (['sen', 'sual'], [(['sen', 'su', 'al'], (1, 2))]),
    'sexuado': (['se', 'xua', 'do'], [(['se', 'xu', 'a', 'do'], (1, 2))]),
    'sexuados': (['se', 'xua', 'dos'], [(['se', 'xu', 'a', 'dos'], (1, 2))]),
    'sexual': (['se', 'xual'], [(['se', 'xu', 'al'], (1, 2))]),
    'suave': (['sua', 've'], [(['su', 'a', 've'], (0, 1))]),
    'televisual': (['te', 'le', 'vi', 'sual'],
                   [(['te', 'le', 'vi', 'su', 'al'], (3, 4))]),
    'textual': (['tex', 'tual'], [(['tex', 'tu', 'al'], (1, 2))]),
    'tiara': (['tia', 'ra'], [(['ti', 'a', 'ra'], (0, 1))]),
    'tiaras': (['tia', 'ras'], [(['ti', 'a', 'ras'], (0, 1))]),
    'tiovivo': (['tio', 'vi', 'vo'], [(['ti', 'o', 'vi', 'vo'], (0, 1))]),
    'tiovivos': (['tio', 'vi', 'vos'], [(['ti', 'o', 'vi', 'vos'], (0, 1))]),
    'traillaba': (['trai', 'lla', 'ba'], [(['tra', 'i', 'lla', 'ba'], (0, 1))]),
    'traillabais': (['trai', 'lla', 'bais'],
                    [(['tra', 'i', 'lla', 'bais'], (0, 1))]),
    'traillaban': (['trai', 'lla', 'ban'],
                   [(['tra', 'i', 'lla', 'ban'], (0, 1))]),
    'traillabas': (['trai', 'lla', 'bas'],
                   [(['tra', 'i', 'lla', 'bas'], (0, 1))]),
    'traillad': (['trai', 'llad'], [(['tra', 'i', 'llad'], (0, 1))]),
    'traillado': (['trai', 'lla', 'do'], [(['tra', 'i', 'lla', 'do'], (0, 1))]),
    'traillamos': (['trai', 'lla', 'mos'],
                   [(['tra', 'i', 'lla', 'mos'], (0, 1))]),
    'traillando': (['trai', 'llan', 'do'],
                   [(['tra', 'i', 'llan', 'do'], (0, 1))]),
    'traillar': (['trai', 'llar'], [(['tra', 'i', 'llar'], (0, 1))]),
    'traillara': (['trai', 'lla', 'ra'], [(['tra', 'i', 'lla', 'ra'], (0, 1))]),
    'traillarais': (['trai', 'lla', 'rais'],
                    [(['tra', 'i', 'lla', 'rais'], (0, 1))]),
    'traillaran': (['trai', 'lla', 'ran'],
                   [(['tra', 'i', 'lla', 'ran'], (0, 1))]),
    'traillaras': (['trai', 'lla', 'ras'],
                   [(['tra', 'i', 'lla', 'ras'], (0, 1))]),
    'traillare': (['trai', 'lla', 're'], [(['tra', 'i', 'lla', 're'], (0, 1))]),
    'traillareis': (['trai', 'lla', 'reis'],
                    [(['tra', 'i', 'lla', 'reis'], (0, 1))]),
    'traillaremos': (['trai', 'lla', 're', 'mos'],
                     [(['tra', 'i', 'lla', 're', 'mos'], (0, 1))]),
    'traillaren': (['trai', 'lla', 'ren'],
                   [(['tra', 'i', 'lla', 'ren'], (0, 1))]),
    'traillares': (['trai', 'lla', 'res'],
                   [(['tra', 'i', 'lla', 'res'], (0, 1))]),
    'traillaron': (['trai', 'lla', 'ron'],
                   [(['tra', 'i', 'lla', 'ron'], (0, 1))]),
    'traillará': (['trai', 'lla', 'rá'], [(['tra', 'i', 'lla', 'rá'], (0, 1))]),
    'traillarán': (['trai', 'lla', 'rán'],
                   [(['tra', 'i', 'lla', 'rán'], (0, 1))]),
    'traillarás': (['trai', 'lla', 'rás'],
                   [(['tra', 'i', 'lla', 'rás'], (0, 1))]),
    'traillaré': (['trai', 'lla', 'ré'], [(['tra', 'i', 'lla', 'ré'], (0, 1))]),
    'traillaréis': (['trai', 'lla', 'réis'],
                    [(['tra', 'i', 'lla', 'réis'], (0, 1))]),
    'traillaría': (['trai', 'lla', 'rí', 'a'],
                   [(['tra', 'i', 'lla', 'rí', 'a'], (0, 1))]),
    'traillaríais': (['trai', 'lla', 'rí', 'ais'],
                     [(['tra', 'i', 'lla', 'rí', 'ais'], (0, 1))]),
    'traillaríamos': (['trai', 'lla', 'rí', 'a', 'mos'],
                      [(['tra', 'i', 'lla', 'rí', 'a', 'mos'], (0, 1))]),
    'traillarían': (['trai', 'lla', 'rí', 'an'],
                    [(['tra', 'i', 'lla', 'rí', 'an'], (0, 1))]),
    'traillarías': (['trai', 'lla', 'rí', 'as'],
                    [(['tra', 'i', 'lla', 'rí', 'as'], (0, 1))]),
    'traillase': (['trai', 'lla', 'se'], [(['tra', 'i', 'lla', 'se'], (0, 1))]),
    'traillaseis': (['trai', 'lla', 'seis'],
                    [(['tra', 'i', 'lla', 'seis'], (0, 1))]),
    'traillasen': (['trai', 'lla', 'sen'],
                   [(['tra', 'i', 'lla', 'sen'], (0, 1))]),
    'traillases': (['trai', 'lla', 'ses'],
                   [(['tra', 'i', 'lla', 'ses'], (0, 1))]),
    'traillaste': (['trai', 'llas', 'te'],
                   [(['tra', 'i', 'llas', 'te'], (0, 1))]),
    'traillasteis': (['trai', 'llas', 'teis'],
                     [(['tra', 'i', 'llas', 'teis'], (0, 1))]),
    'traillemos': (['trai', 'lle', 'mos'],
                   [(['tra', 'i', 'lle', 'mos'], (0, 1))]),
    'traillá': (['trai', 'llá'], [(['tra', 'i', 'llá'], (0, 1))]),
    'traillábamos': (['trai', 'llá', 'ba', 'mos'],
                     [(['tra', 'i', 'llá', 'ba', 'mos'], (0, 1))]),
    'trailláis': (['trai', 'lláis'], [(['tra', 'i', 'lláis'], (0, 1))]),
    'trailláramos': (['trai', 'llá', 'ra', 'mos'],
                     [(['tra', 'i', 'llá', 'ra', 'mos'], (0, 1))]),
    'trailláremos': (['trai', 'llá', 're', 'mos'],
                     [(['tra', 'i', 'llá', 're', 'mos'], (0, 1))]),
    'traillás': (['trai', 'llás'], [(['tra', 'i', 'llás'], (0, 1))]),
    'traillásemos': (['trai', 'llá', 'se', 'mos'],
                     [(['tra', 'i', 'llá', 'se', 'mos'], (0, 1))]),
    'traillé': (['trai', 'llé'], [(['tra', 'i', 'llé'], (0, 1))]),
    'trailléis': (['trai', 'lléis'], [(['tra', 'i', 'lléis'], (0, 1))]),
    'trailló': (['trai', 'lló'], [(['tra', 'i', 'lló'], (0, 1))]),
    'transexual': (['tran', 'se', 'xual'],
                   [(['tran', 'se', 'xu', 'al'], (2, 3))]),
    'trasoiremos': (['tra', 'soi', 're', 'mos'],
                    [(['tra', 'so', 'i', 're', 'mos'], (1, 2))]),
    'trasoirá': (['tra', 'soi', 'rá'], [(['tra', 'so', 'i', 'rá'], (1, 2))]),
    'trasoirán': (['tra', 'soi', 'rán'], [(['tra', 'so', 'i', 'rán'], (1, 2))]),
    'trasoirás': (['tra', 'soi', 'rás'], [(['tra', 'so', 'i', 'rás'], (1, 2))]),
    'trasoiré': (['tra', 'soi', 'ré'], [(['tra', 'so', 'i', 'ré'], (1, 2))]),
    'trasoiréis': (['tra', 'soi', 'réis'],
                   [(['tra', 'so', 'i', 'réis'], (1, 2))]),
    'trasoiría': (['tra', 'soi', 'rí', 'a'],
                  [(['tra', 'so', 'i', 'rí', 'a'], (1, 2))]),
    'trasoiríais': (['tra', 'soi', 'rí', 'ais'],
                    [(['tra', 'so', 'i', 'rí', 'ais'], (1, 2))]),
    'trasoiríamos': (['tra', 'soi', 'rí', 'a', 'mos'],
                     [(['tra', 'so', 'i', 'rí', 'a', 'mos'], (1, 2))]),
    'trasoirían': (['tra', 'soi', 'rí', 'an'],
                   [(['tra', 'so', 'i', 'rí', 'an'], (1, 2))]),
    'trasoirías': (['tra', 'soi', 'rí', 'as'],
                   [(['tra', 'so', 'i', 'rí', 'as'], (1, 2))]),
    'trial': (['trial'], [(['tri', 'al'], (0, 1))]),
    'triales': (['tria', 'les'], [(['tri', 'a', 'les'], (0, 1))]),
    'trianual': (['tria', 'nual'], [(['tria', 'nu', 'al'], (1, 2))]),
    'trienio': (['trie', 'nio'], [(['tri', 'e', 'nio'], (0, 1))]),
    'trienios': (['trie', 'nios'], [(['tri', 'e', 'nios'], (0, 1))]),
    'trimensual': (['tri', 'men', 'sual'],
                   [(['tri', 'men', 'su', 'al'], (2, 3))]),
    'unisexuado': (['u', 'ni', 'se', 'xua', 'do'],
                   [(['u', 'ni', 'se', 'xu', 'a', 'do'], (3, 4))]),
    'unisexuados': (['u', 'ni', 'se', 'xua', 'dos'],
                    [(['u', 'ni', 'se', 'xu', 'a', 'dos'], (3, 4))]),
    'unisexual': (['u', 'ni', 'se', 'xual'],
                  [(['u', 'ni', 'se', 'xu', 'al'], (3, 4))]),
    'usual': (['u', 'sual'], [(['u', 'su', 'al'], (1, 2))]),
    'viable': (['via', 'ble'], [(['vi', 'a', 'ble'], (0, 1))]),
    'viables': (['via', 'bles'], [(['vi', 'a', 'bles'], (0, 1))]),
    'viajar': (['via', 'jar'], [(['vi', 'a', 'jar'], (0, 1))]),
    'viajares': (['via', 'ja', 'res'], [(['vi', 'a', 'ja', 'res'], (0, 1))]),
    'viaje': (['via', 'je'], [(['vi', 'a', 'je'], (0, 1))]),
    'viajes': (['via', 'jes'], [(['vi', 'a', 'jes'], (0, 1))]),
    'virtual': (['vir', 'tual'], [(['vir', 'tu', 'al'], (2, 2))]),
    'visual': (['vi', 'sual'], [(['vi', 'su', 'al'], (1, 2))]),
    'visuales': (['vi', 'sua', 'les'], [(['vi', 'su', 'a', 'les'], (1, 2))]),
    'viudo': (['viu', 'do'], [(['vi', 'u', 'do'], (0, 1))]),
    'viudos': (['viu', 'dos'], [(['vi', 'u', 'dos'], (0, 1))])}
